@@ -15,7 +15,7 @@
  * Authors:
  *     Andy Cress <arcress@users.sourceforge.net>
  *     Peter D. Phan <pdphan@users.sourceforge.net>
- *     Renier Morales <renierm@users.sf.net>
+ *     Renier Morales <renier@openhpi.org>
  *     Tariq Shureih <tariq.shureih@intel.com>
  *     Racing Guo <racing.guo@intel.com>
  *
@@ -33,15 +33,16 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <SaHpi.h>
+#include <oh_clients.h>
 #ifdef OPENHPI_USED
 #include <oh_utils.h>
 #endif
 
+#define OH_SVN_REV "$Revision: 6571 $"
+
 #define NCT 25
 #define MAX_STRSIZE  64
 
-char progver[] = "1.5 HPI-B";
-char progname[] = "hpiinv";
 char *chasstypes[NCT] = {
 	"Not Defined", "Other", "Unknown", "Desktop", "Low Profile Desktop",
 	"Pizza Box", "Mini Tower", "Tower", "Portable", "Laptop",
@@ -469,7 +470,7 @@ main(int argc, char **argv)
   int invfound = 0;
   int nloops = 0;
 
-  printf("%s ver %s\n",progname,progver);
+  oh_prog_version(argv[0], OH_SVN_REV);
   atag.tlen = 0;
 
   while ( (c = getopt( argc, argv,"a:vxz?")) != EOF )
@@ -485,7 +486,7 @@ main(int argc, char **argv)
 	  }
           break;
     default:
-          printf("Usage: %s [-x] [-a asset_tag]\n", progname);
+          printf("Usage: %s [-x] [-a asset_tag]\n", argv[0]);
           printf("   -a  Sets the asset tag\n");
           printf("   -x  Display debug messages\n");
           printf("   -z  Display extra debug messages\n");
