@@ -15,7 +15,7 @@
  * Changes:
  *      11.30.2004 - Kouzmich < Mikhail.V.Kouzmich@intel.com >:
  *                      porting to HPI-B
- *      09.07.2005 - Renier Morales <renierm@users.sf.net>:
+ *      09.07.2005 - Renier Morales <renier@openhpi.org>:
  *                      Changes due to move of oh_add_config_file to config.c
  *
  *
@@ -178,9 +178,9 @@ static ret_code_t debugset(void)
         if (debug_flag) printf("debugset:\n");
         term = get_next_term();
         if (term == NULL) {
-                val = getenv("OPENHPI_DEBUG");
+                val = getenv("OPENHPI_ERROR");
                 if (val == (char *)NULL) val = "NO";
-                printf("OPENHPI_DEBUG=%s\n", val);
+                printf("OPENHPI_ERROR=%s\n", val);
                 return(HPI_SHELL_OK);
         };
         if (strcmp(term->term, "on") == 0)
@@ -189,7 +189,7 @@ static ret_code_t debugset(void)
                 val = "NO";
         else
                 return HPI_SHELL_PARM_ERROR;
-        setenv("OPENHPI_DEBUG", val, 1);
+        setenv("OPENHPI_ERROR", val, 1);
 
         return HPI_SHELL_OK;
 }
@@ -358,7 +358,7 @@ static ret_code_t set_tag(void)
         strcpy((char *)(tbuf.Data), buf);
         tbuf.DataType = SAHPI_TL_TYPE_TEXT;
         tbuf.Language = SAHPI_LANG_ENGLISH;
-        tbuf.DataLength = i;
+        tbuf.DataLength = strlen(buf);
         rv = saHpiResourceTagSet(Domain->sessionId, resid, &tbuf);
         if (rv != SA_OK) {
                 printf("saHpiResourceTagSet error = %s\n", oh_lookup_error(rv));
@@ -746,29 +746,28 @@ static ret_code_t show_rdr(void)
         term = get_next_term();
         if (term == NULL) {
                 if (read_file) return(HPI_SHELL_CMD_ERROR);
-                i = get_string_param("RDR Type (s|a|c|w|i|all) ==> ",
+                i = get_string_param("RDR Type (s|a|c|w|i|d|f) ==> ",
                         buf, 9);
-                if (i != 0) return HPI_SHELL_PARM_ERROR;
+                if (i != 0 || strnlen(buf, 3) > 1)
+			return HPI_SHELL_PARM_ERROR;
         } else {
                 memset(buf, 0, 10);
                 strncpy(buf, term->term, 3);
         };
-        if (strncmp(buf, "all", 3) == 0) t = 'n';
-        else t = *buf;
+        t = *buf;
         if (t == 'c') type = SAHPI_CTRL_RDR;
         else if (t == 's') type = SAHPI_SENSOR_RDR;
         else if (t == 'i') type = SAHPI_INVENTORY_RDR;
         else if (t == 'w') type = SAHPI_WATCHDOG_RDR;
         else if (t == 'a') type = SAHPI_ANNUNCIATOR_RDR;
-        else type = SAHPI_NO_RECORD;
+        else if (t == 'd') type = SAHPI_DIMI_RDR;
+        else if (t == 'f') type = SAHPI_FUMI_RDR;
+        else return HPI_SHELL_PARM_ERROR;
         ret = ask_rdr(rptid, type, &rdrnum);
         if (ret != HPI_SHELL_OK) return(ret);
-        if (type == SAHPI_NO_RECORD)
-                rv = find_rdr_by_num(Domain->sessionId, rptid,
-                        rdrnum, type, 0, &rdr_entry);
-        else
-                rv = saHpiRdrGetByInstrumentId(Domain->sessionId,
-                        rptid, type, rdrnum, &rdr_entry);
+
+	rv = saHpiRdrGetByInstrumentId(Domain->sessionId,
+		rptid, type, rdrnum, &rdr_entry);
         if (rv != SA_OK) {
                 printf("ERROR!!! Get rdr: ResourceId=%d RdrType=%d"
                         "RdrNum=%d: %s\n",
@@ -1061,6 +1060,36 @@ static ret_code_t quit(void)
         exit(0);
 }
 
+static ret_code_t reopen_session(void)
+{
+        int              eflag = 0, fflag = 0;
+        term_def_t      *term;
+        SaErrorT         rv;
+   
+        term = get_next_term();
+        while (term != NULL) {
+                if (strcmp(term->term, "force") == 0) {
+                        fflag = 1;
+                } else {
+                        printf("Invalid argument: %s\n", term->term);
+                        return(HPI_SHELL_PARM_ERROR);
+                };
+                term = get_next_term();
+        };
+        do {
+           rv = saHpiSessionClose(Domain->sessionId);
+           sleep( 1 );
+        } while ( fflag == 0 && rv != SA_OK && rv != SA_ERR_HPI_NO_RESPONSE );
+        if (rv != SA_OK) {
+                printf("saHpiSessionClose error %s\n", oh_lookup_error(rv));
+        }
+        if (open_session(eflag) != 0) {
+                printf("Can not open session\n");
+                return(HPI_SHELL_CMD_ERROR);
+        }
+        return(HPI_SHELL_OK);
+}
+
 static ret_code_t run(void)
 {
         term_def_t      *term;
@@ -1247,7 +1276,10 @@ const char ctrlhelp[] = "ctrl: control command block\n"
                         "       ctrlId:: <resourceId> <num>\n";
 const char dathelp[] = "dat: domain alarm table list\n"
                         "Usage: dat";
-const char debughelp[] = "debug: set or unset OPENHPI_DEBUG environment\n"
+const char dimiblockhelp[] = "dimi: DIMI command block\n"
+                        "Usage: dimi [<DimiId>]\n"
+                        "       DimiId:: <resourceId> <DimiNum>\n";
+const char debughelp[] = "debug: set or unset OPENHPI_ERROR environment\n"
                         "Usage: debug [ on | off ]";
 const char domainhelp[] = "domain: show domain list and set current domain\n"
                         "Usage: domain [<domain id>]";
@@ -1267,6 +1299,9 @@ const char evtlogtimehelp[] = "evtlogtime: show the event log's clock\n"
                         "Usage: evtlogtime [<resource id>]";
 const char exechelp[] = "exec: execute external program\n"
                         "Usage: exec <filename> [parameters]";
+const char fumiblockhelp[] = "fumi: FUMI command block\n"
+                        "Usage: fumi [<FumiId>]\n"
+                        "       DimiId:: <resourceId> <FumiNum>\n";
 const char helphelp[] = "help: help information for OpenHPI commands\n"
                         "Usage: help [optional commands]";
 const char historyhelp[] = "history: show input commands history\n"
@@ -1295,6 +1330,9 @@ const char quithelp[] = "quit: close session and quit console\n"
                         "Usage: quit";
 const char resethelp[] = "reset: perform specified reset on the entity\n"
                         "Usage: reset <resource id> [cold|warm|assert|deassert]";
+const char reopenhelp[] = "reopen: reopens session\n"
+                        "Usage: reopen [force]\n"
+                          "force flag skips old session closing check";
 const char runhelp[] = "run: execute command file\n"
                         "Usage: run <file name>";
 const char senhelp[] =  "sen: sensor command block\n"
@@ -1314,7 +1352,7 @@ const char showrdrhelp[] = "showrdr: show resource data record\n"
                         "Usage: showrdr [<resource id> [type [<rdr num>]]]\n"
                         "   or  rdr [<resource id> [type [<rdr num>]]]\n"
                         "       type =  c - control rdr, s - sensor, i - inventory rdr\n"
-                        "               w - watchdog, a - annunciator, all - all rdr";
+                        "               w - watchdog, a - annunciator";
 const char showrpthelp[] = "showrpt: show resource information\n"
                         "Usage: showrpt [<resource id>]\n"
                         "   or  rpt [<resource id>]";
@@ -1342,18 +1380,18 @@ const char sen_setthhelp[] = "setthres: set sensor thresholds\n"
 const char sen_showhelp[] = "show: show sensor state\n"
                         "Usage: show";
 //  inventory command block
-const char inv_addahelp[] = "addarea: add inventoty area\n"
+const char inv_addahelp[] = "addarea: add inventory area\n"
                         "Usage: addarea";
-const char inv_addfhelp[] = "addfield: add inventoty field\n"
+const char inv_addfhelp[] = "addfield: add inventory field\n"
                         "Usage: addfield";
-const char inv_delahelp[] = "delarea: delete inventoty area\n"
+const char inv_delahelp[] = "delarea: delete inventory area\n"
                         "Usage: delarea";
-const char inv_delfhelp[] = "delfield: delete inventoty field\n"
+const char inv_delfhelp[] = "delfield: delete inventory field\n"
                         "Usage: delfield";
-const char inv_setfhelp[] = "setfield: set inventoty field\n"
+const char inv_setfhelp[] = "setfield: set inventory field\n"
                         "Usage: setfield";
-const char inv_showhelp[] = "show: show inventoty\n"
-                        "Usage: show";
+const char inv_showhelp[] = "show: show inventory\n"
+                        "Usage: show [<area id>]";
 //  control command block
 const char ctrl_setsthelp[] = "setstate: set control state\n"
                         "Usage: setstate <values>";
@@ -1393,6 +1431,52 @@ const char hs_settohelp[] = "settimeout: set timeout\n"
                         "Usage: settimeout insert|extract <value>";
 const char hs_statehelp[] = "state: show hot swap state\n"
                         "Usage: state";
+//  DIMI command block
+const char dimi_infohelp[] = "info: shows information about DIMI\n"
+                        "Usage: info";
+const char dimi_testinfohelp[] = "testinfo: shows information about specified test\n"
+                        "Usage: testinfo [<testNum>]";
+const char dimi_readyhelp[] = "ready: shows information about the DIMI readiness to run specified test\n"
+                        "Usage: ready <testNum>";
+const char dimi_starthelp[] = "start: starts execution of specified test\n"
+                        "Usage: start <testNum>";
+const char dimi_cancelhelp[] = "cancel: cancels specified test running\n"
+                        "Usage: cancel <testNum>";
+const char dimi_statushelp[] = "status: shows status of specified test\n"
+                        "Usage: status <testNum>";
+const char dimi_resultshelp[] = "results: show results from the last run of specified test\n"
+                        "Usage: results <testNum>";
+//  FUMI command block
+const char fumi_setsourcehelp[] = "setsource : set new source information to the specified bank\n"
+                        "Usage: setsource <bankNum> <sourceURI>";
+const char fumi_validatesourcehelp[] = "validatesource : initiates the validation of the integrity of "
+                        "the source image associated with the designated bank\n"
+                        "Usage: validatesource <bankNum>";
+const char fumi_getsourcehelp[] = "getsource : shows information about the source image assigned to "
+                        "designated bank\n"
+                        "Usage: getsource <bankNum>";
+const char fumi_targetinfohelp[] = "targetinfo : shows information about the specified bank\n"
+                        "Usage: targetinfo <bankNum>";
+const char fumi_backuphelp[] = "backup : initiates a backup of currently active bank\n"
+                        "Usage: backup";
+const char fumi_setbootorderhelp[] = "setbootorder : set the position of a bank in the boot order\n"
+                        "Usage: setbootorder <bankNum> <position>";
+const char fumi_bankcopyhelp[] = "bankcopy : initiates a copy of the contents of one bank to another bank\n"
+                        "Usage: bankcopy <srcBankNum> <dstBankNum>";
+const char fumi_installhelp[] = "install : starts an installation process, loading firmware to "
+                        "a specified bank\n"
+                        "Usage: install <bankNum>";
+const char fumi_statushelp[] = "status : shows upgrade status of the FUMI\n"
+                        "Usage: status <bankNum>";
+const char fumi_verifytargethelp[] = "verifytarget : starts the verification process of the upgraded image\n"
+                        "Usage: verifytarget <bankNum>";
+const char fumi_cancelhelp[] = "cancel : stops upgrade asynchronous operation in progress\n"
+                        "Usage: cancel <bankNum>";
+const char fumi_rollbackhelp[] = "rollback : initiates a rollback operation to "
+                        "restore the currently active bank with a backup version\n"
+                        "Usage: rollback ";
+const char fumi_activatehelp[] = "activate : starts execution of the active image on the FUMI\n"
+                        "Usage: activate ";
 
 command_def_t commands[] = {
     { "addcfg",         add_config,     addcfghelp,     MAIN_COM },
@@ -1401,6 +1485,7 @@ command_def_t commands[] = {
     { "ctrl",           ctrl_block,     ctrlhelp,       MAIN_COM },
     { "dat",            dat_list,       dathelp,        MAIN_COM },
     { "debug",          debugset,       debughelp,      UNDEF_COM },
+    { "dimi",           dimi_block,     dimiblockhelp,  MAIN_COM },
     { "domain",         domain_proc,    domainhelp,     MAIN_COM },
     { "domaininfo",     domain_info,    domaininfohelp, MAIN_COM },
     { "dscv",           discovery,      dscvhelp,       MAIN_COM },
@@ -1410,6 +1495,7 @@ command_def_t commands[] = {
     { "evtlogreset",    evtlog_reset,   evtlresethelp,  MAIN_COM },
     { "evtlogstate",    evtlog_state,   evtlstatehelp,  MAIN_COM },
     { "exec",           exec_proc,      exechelp,       UNDEF_COM },
+    { "fumi",           fumi_block,     fumiblockhelp,  MAIN_COM },
     { "help",           help_cmd,       helphelp,       UNDEF_COM },
     { "history",        history_cmd,    historyhelp,    UNDEF_COM },
     { "hs",             hs_block,       hsblockhelp,    MAIN_COM },
@@ -1421,6 +1507,7 @@ command_def_t commands[] = {
     { "power",          power,          powerhelp,      MAIN_COM },
     { "quit",           quit,           quithelp,       UNDEF_COM },
     { "rdr",            show_rdr,       showrdrhelp,    MAIN_COM },
+    { "reopen",         reopen_session, reopenhelp,     UNDEF_COM },
     { "reset",          reset,          resethelp,      MAIN_COM },
     { "rpt",            show_rpt,       showrpthelp,    MAIN_COM },
     { "run",            run,            runhelp,        MAIN_COM },
@@ -1476,5 +1563,28 @@ command_def_t commands[] = {
     { "policycancel",   hs_block_policy,hs_policyhelp,  HS_COM },
     { "settimeout",     hs_block_stime, hs_settohelp,   HS_COM },
     { "state",          hs_block_state, hs_statehelp,   HS_COM },
+// DIMI command block
+    { "info",           dimi_block_info,     dimi_infohelp,     DIMI_COM },
+    { "testinfo",       dimi_block_testinfo, dimi_testinfohelp, DIMI_COM },
+    { "ready",          dimi_block_ready,    dimi_readyhelp,    DIMI_COM },
+    { "start",          dimi_block_start,    dimi_starthelp,    DIMI_COM },
+    { "cancel",         dimi_block_cancel,   dimi_cancelhelp,   DIMI_COM },
+    { "status",         dimi_block_status,   dimi_statushelp,   DIMI_COM },
+    { "results",        dimi_block_results,  dimi_resultshelp,  DIMI_COM },
+// FUMI command block
+    { "setsource",      fumi_block_setsource,      fumi_setsourcehelp,       FUMI_COM },
+    { "validatesource", fumi_block_validatesource, fumi_validatesourcehelp,  FUMI_COM },
+    { "getsource",      fumi_block_getsource,      fumi_getsourcehelp,       FUMI_COM },
+    { "targetinfo",     fumi_block_targetinfo,     fumi_targetinfohelp,      FUMI_COM },
+    { "backup",         fumi_block_backup,         fumi_backuphelp,          FUMI_COM },
+    { "setbootorder",   fumi_block_setbootorder,   fumi_setbootorderhelp,    FUMI_COM },
+    { "bankcopy",       fumi_block_bankcopy,       fumi_bankcopyhelp,        FUMI_COM },
+    { "install",        fumi_block_install,        fumi_installhelp,         FUMI_COM },
+    { "status",         fumi_block_status,         fumi_statushelp,          FUMI_COM },
+    { "verifytarget",   fumi_block_verifytarget,   fumi_verifytargethelp,    FUMI_COM },
+    { "cancel",         fumi_block_cancel,         fumi_cancelhelp,          FUMI_COM },
+    { "rollback",       fumi_block_rollback,       fumi_rollbackhelp,        FUMI_COM },
+    { "activate",       fumi_block_activate,       fumi_activatehelp,        FUMI_COM },
+// Terminator
     { NULL,             NULL,           NULL,           MAIN_COM }
 };
