@@ -13,7 +13,7 @@
  * Authors:
  *     Louis Zhuang <louis.zhuang@linux.intel.com>
  *     Sean Dague <http://dague.net/sean>
- *     Renier Morales <renierm@users.sourceforge.net>
+ *     Renier Morales <renier@openhpi.org>
  *     Racing Guo <racing.guo@intel.com>
  */
 
@@ -226,6 +226,13 @@ struct oh_abi_v2 {
 				SaHpiResourceIdT id,
 				SaHpiEventLogInfoT *info);
 
+        /***
+         * saHpiEventLogCapabilitiesGet
+         **/
+        SaErrorT (*get_el_caps)(void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiEventLogCapabilitiesT *caps);
+
         /***
          * saHpiEventLogTimeSet
          **/
@@ -398,6 +405,15 @@ struct oh_abi_v2 {
 				 SaHpiIdrIdT idrid,
 				 SaHpiIdrAreaTypeT areatype,
 				 SaHpiEntryIdT *areaid);
+                                 
+        /***
+         * saHpiIdrAreaAddById
+         **/
+        SaErrorT (*add_idr_area_id)(void *,
+                                    SaHpiResourceIdT,
+                                    SaHpiIdrIdT,
+                                    SaHpiIdrAreaTypeT,
+                                    SaHpiEntryIdT);
 
         /***
          * saHpiIdrAreaDelete
@@ -427,6 +443,14 @@ struct oh_abi_v2 {
 				  SaHpiIdrIdT idrid,
 				  SaHpiIdrFieldT *field);
 
+        /***
+         * saHpiIdrFieldAddById
+         **/
+        SaErrorT (*add_idr_field_id)(void *hnd,
+                                     SaHpiResourceIdT rid,
+                                     SaHpiIdrIdT idrid,
+                                     SaHpiIdrFieldT *field);
+
         /***
          * saHpiIdrFieldSet
          **/
@@ -537,7 +561,203 @@ struct oh_abi_v2 {
 				    SaHpiResourceIdT id,
                                     SaHpiAnnunciatorNumT num,
 				    SaHpiAnnunciatorModeT mode);
+				    
+	/***************
+	 * DIMI ABIs
+	 ***************/
+	 
+	/***
+	 * saHpiDimiInfoGet
+	 **/
+	SaErrorT (*get_dimi_info)(void *hnd,
+				  SaHpiResourceIdT id,
+				  SaHpiDimiNumT num,
+				  SaHpiDimiInfoT *info);
 
+        /***
+         * saHpiDimiTestInfoGet
+         **/
+        SaErrorT (*get_dimi_test)(void *hnd,
+                                  SaHpiResourceIdT id,
+                                  SaHpiDimiNumT num,
+                                  SaHpiDimiTestNumT testnum,
+                                  SaHpiDimiTestT *test);
+
+        /***
+         * saHpiDimiTestReadinessGet
+         **/
+        SaErrorT (*get_dimi_test_ready)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiDimiNumT num,
+                                SaHpiDimiTestNumT testnum,
+                                SaHpiDimiReadyT *ready);
+
+        /***
+         * saHpiDimiTestStart
+         **/
+        SaErrorT (*start_dimi_test)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiDimiNumT num,
+                                SaHpiDimiTestNumT testnum,
+                                SaHpiUint8T numparams,
+                                SaHpiDimiTestVariableParamsT *paramslist);
+
+        /***
+         * saHpiDimiTestCancel
+         **/
+        SaErrorT (*cancel_dimi_test)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiDimiNumT num,
+                                SaHpiDimiTestNumT testnum);
+
+        /***
+         * saHpiDimiTestStatusGet
+         **/
+        SaErrorT (*get_dimi_test_status)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiDimiNumT num,
+                                SaHpiDimiTestNumT testnum,
+                                SaHpiDimiTestPercentCompletedT *percentcompleted,
+                                SaHpiDimiTestRunStatusT *runstatus);
+
+        /***
+         * saHpiDimiTestResultsGet
+         **/
+        SaErrorT (*get_dimi_test_results)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiDimiNumT num,
+                                SaHpiDimiTestNumT testnum,
+                                SaHpiDimiTestResultsT *testresults);
+
+        /***************
+         * FUMI ABIs
+         ***************/
+
+        /***
+         * saHpiFumiSourceSet
+         **/
+        SaErrorT (*set_fumi_source)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum,
+                                SaHpiTextBufferT *sourceuri);
+
+        /***
+         * saHpiFumiSourceInfoValidateStart
+         **/
+        SaErrorT (*validate_fumi_source)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum);
+
+        /***
+         * saHpiFumiSourceInfoGet
+         **/
+        SaErrorT (*get_fumi_source)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum,
+                                SaHpiFumiSourceInfoT *sourceinfo);
+
+        /***
+         * saHpiFumiTargetInfoGet
+         **/
+        SaErrorT (*get_fumi_target)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum,
+                                SaHpiFumiBankInfoT *bankinfo);
+
+        /***
+         * saHpiFumiBackupStart
+         **/
+        SaErrorT (*start_fumi_backup)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num);
+
+        /***
+         * saHpiFumiBankBootOrderSet
+         **/
+        SaErrorT (*set_fumi_bank_order)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum,
+                                SaHpiUint32T position);
+
+        /***
+         * saHpiFumiBankBootOrderSet
+         **/
+        SaErrorT (*start_fumi_bank_copy)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT sourcebanknum,
+                                SaHpiBankNumT targetbanknum);
+
+        /***
+         * saHpiFumiInstallStart
+         **/
+        SaErrorT (*start_fumi_install)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum);
+
+        /***
+         * saHpiFumiUpgradeStatusGet
+         **/
+        SaErrorT (*get_fumi_status)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum,
+                                SaHpiFumiUpgradeStatusT *status);
+
+        /***
+         * saHpiFumiTargetVerifyStart
+         **/
+        SaErrorT (*start_fumi_verify)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum);
+
+        /***
+         * saHpiFumiUpgradeCancel
+         **/
+        SaErrorT (*cancel_fumi_upgrade)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum);
+
+        /***
+         * saHpiFumiRollback
+         **/
+        SaErrorT (*rollback_fumi)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num);
+
+        /***
+         * saHpiFumiRollback
+         **/
+        SaErrorT (*activate_fumi)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num);
+        
 	/***************
 	 * HOTSWAP ABIs
 	 ***************/
@@ -622,17 +842,35 @@ struct oh_abi_v2 {
 				    SaHpiResourceIdT id,
                                	    SaHpiPowerStateT state);
 
-	/****************
+	/*****************
 	 * PARAMETER ABIs
 	 *****************/
 
-	/***
+        /***
          * saHpiParmControl
          **/
         SaErrorT (*control_parm)(void *hnd,
 				 SaHpiResourceIdT id,
 				 SaHpiParmActionT act);
 
+        /***********************
+         * Load Management ABIs
+         ***********************/
+     
+        /***
+         * saHpiResourceLoadIdGet
+         **/
+        SaErrorT (*load_id_get)(void *hnd,
+                                SaHpiResourceIdT rid,
+                                SaHpiLoadIdT *load_id);
+
+        /***
+         * saHpiResourceLoadIdSet
+         **/
+        SaErrorT (*load_id_set)(void *hnd,
+                                SaHpiResourceIdT rid,
+                                SaHpiLoadIdT *load_id);
+                                
 	/*************
 	 * RESET ABIs
 	 *************/
