@@ -13,25 +13,13 @@
  * Authors:
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
  *     W. David Ashley <dashley@us.ibm.com.com>
+ *     Renier Morales <renier@openhpi.org>
  */
 
 #include "marshal_hpi.h"
 #include <stdio.h>
 
 
-static const cMarshalType *saHpiVersionGetIn[] =
-{
-  0
-};
-
-
-static const cMarshalType *saHpiVersionGetOut[] =
-{
-  &SaHpiVersionType, // result (SaHpiVersionT)
-  0
-};
-
-
 static const cMarshalType *saHpiSessionOpenIn[] =
 {
   &SaHpiDomainIdType, // domain id (SaHpiDomainIdT)
@@ -197,6 +185,58 @@ static const cMarshalType *saHpiResourceIdGetOut[] =
 };
 
 
+static const cMarshalType *saHpiGetIdByEntityPathIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiEntityPathType,
+  &SaHpiRdrTypeType,
+  &SaHpiUint32Type,
+  0
+};
+
+static const cMarshalType *saHpiGetIdByEntityPathOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiUint32Type,
+  &SaHpiResourceIdType,
+  &SaHpiInstrumentIdType,
+  &SaHpiUint32Type,
+  0
+};
+
+
+static const cMarshalType *saHpiGetChildEntityPathIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiEntityPathType,
+  &SaHpiUint32Type,
+  0
+};
+
+static const cMarshalType *saHpiGetChildEntityPathOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiUint32Type,
+  &SaHpiEntityPathType,
+  &SaHpiUint32Type,
+  0
+};
+
+
+static const cMarshalType *saHpiResourceFailedRemoveIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  0
+};
+
+static const cMarshalType *saHpiResourceFailedRemoveOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  0
+};
+
+
 static const cMarshalType *saHpiEventLogInfoGetIn[] =
 {
   &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
@@ -212,6 +252,21 @@ static const cMarshalType *saHpiEventLogInfoGetOut[] =
 };
 
 
+static const cMarshalType *saHpiEventLogCapabilitiesGetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  0
+};
+
+static const cMarshalType *saHpiEventLogCapabilitiesGetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiEventLogCapabilitiesType,
+  0
+};
+
+
 static const cMarshalType *saHpiEventLogEntryGetIn[] =
 {
   &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
@@ -774,6 +829,23 @@ static const cMarshalType *saHpiIdrAreaAddOut[] =
 };
 
 
+static const cMarshalType *saHpiIdrAreaAddByIdIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  &SaHpiIdrIdType,
+  &SaHpiIdrAreaTypeType,
+  &SaHpiEntryIdType,
+  0
+};
+
+static const cMarshalType *saHpiIdrAreaAddByIdOut[] =
+{
+  &SaErrorType,            // result (SaErrorT)
+  0
+};
+
+
 static const cMarshalType *saHpiIdrAreaDeleteIn[] =
 {
   &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
@@ -822,7 +894,24 @@ static const cMarshalType *saHpiIdrFieldAddIn[] =
 static const cMarshalType *saHpiIdrFieldAddOut[] =
 {
   &SaErrorType,            // result (SaErrorT)
-  &SaHpiIdrFieldTypeType,
+  &SaHpiIdrFieldType,
+  0
+};
+
+
+static const cMarshalType *saHpiIdrFieldAddByIdIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  &SaHpiIdrIdType,
+  &SaHpiIdrFieldType,
+  0
+};
+
+static const cMarshalType *saHpiIdrFieldAddByIdOut[] =
+{
+  &SaErrorType,            // result (SaErrorT)
+  &SaHpiIdrFieldType,
   0
 };
 
@@ -1025,7 +1114,303 @@ static const cMarshalType *saHpiAnnunciatorModeSetOut[] =
   0
 };
 
+// DIMIs
+static const cMarshalType *saHpiDimiInfoGetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  &SaHpiDimiNumType,
+  0
+};
 
+static const cMarshalType *saHpiDimiInfoGetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiDimiInfoType,
+  0
+};
+
+
+static const cMarshalType *saHpiDimiTestInfoGetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  &SaHpiDimiNumType,
+  &SaHpiDimiTestNumType,
+  0
+};
+
+static const cMarshalType *saHpiDimiTestInfoGetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiDimiTestType,
+  0
+};
+
+static const cMarshalType *saHpiDimiTestReadinessGetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  &SaHpiDimiNumType,
+  &SaHpiDimiTestNumType,
+  0
+};
+
+static const cMarshalType *saHpiDimiTestReadinessGetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiDimiReadyType,
+  0
+};
+
+static const cMarshalType *saHpiDimiTestStartIn[] =
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiDimiNumType,
+        &SaHpiDimiTestNumType,
+        &SaHpiDimiTestVariableParamsListType,
+        0
+};
+static const cMarshalType *saHpiDimiTestStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiDimiTestCancelIn[] =
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiDimiNumType,
+        &SaHpiDimiTestNumType,
+        0
+};
+static const cMarshalType *saHpiDimiTestCancelOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiDimiTestStatusGetIn[] =
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiDimiNumType,
+        &SaHpiDimiTestNumType,
+        0
+};
+static const cMarshalType *saHpiDimiTestStatusGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiDimiTestPercentCompletedType,
+        &SaHpiDimiTestRunStatusType,
+        0
+};
+
+static const cMarshalType *saHpiDimiTestResultsGetIn[] =
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiDimiNumType,
+        &SaHpiDimiTestNumType,
+        0
+};
+static const cMarshalType *saHpiDimiTestResultsGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiDimiTestResultsType,
+        0
+};
+
+// FUMIs
+static const cMarshalType *saHpiFumiSourceSetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+	&SaHpiTextBufferType,
+        0
+};
+static const cMarshalType *saHpiFumiSourceSetOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiSourceInfoValidateStartIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiSourceInfoValidateStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiSourceInfoGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiSourceInfoGetOut[] =
+{
+        &SaErrorType,
+	&SaHpiFumiSourceInfoType,
+        0
+};
+
+static const cMarshalType *saHpiFumiTargetInfoGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiTargetInfoGetOut[] =
+{
+        &SaErrorType,
+	&SaHpiFumiBankInfoType,
+        0
+};
+
+static const cMarshalType *saHpiFumiBackupStartIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiBackupStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiBankBootOrderSetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+	&SaHpiUint32Type,
+        0
+};
+static const cMarshalType *saHpiFumiBankBootOrderSetOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiBankCopyStartIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiBankCopyStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiInstallStartIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiInstallStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiUpgradeStatusGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiUpgradeStatusGetOut[] =
+{
+        &SaErrorType,
+	&SaHpiFumiUpgradeStatusType,
+        0
+};
+
+static const cMarshalType *saHpiFumiTargetVerifyStartIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiTargetVerifyStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiUpgradeCancelIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiUpgradeCancelOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiRollbackIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiRollbackOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+static const cMarshalType *saHpiFumiActivateIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiActivateOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+
+// Hotswap
 static const cMarshalType *saHpiHotSwapPolicyCancelIn[] =
 {
   &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
@@ -1201,6 +1586,36 @@ static const cMarshalType *saHpiParmControlOut[] =
 };
 
 
+static const cMarshalType *saHpiResourceLoadIdGetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  0
+};
+
+static const cMarshalType *saHpiResourceLoadIdGetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiLoadIdType,
+  0
+};
+
+
+static const cMarshalType *saHpiResourceLoadIdSetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  &SaHpiLoadIdType,
+  0
+};
+
+static const cMarshalType *saHpiResourceLoadIdSetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  0
+};
+
+
 static const cMarshalType *saHpiResourceResetStateGetIn[] =
 {
   &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
@@ -1260,36 +1675,12 @@ static const cMarshalType *saHpiResourcePowerStateSetOut[] =
   0
 };
 
-static const cMarshalType *oHpiHandlerCreateInitIn[] =
-{
-  &SaErrorType, // dummy entry
-  0
-};
-
-static const cMarshalType *oHpiHandlerCreateInitOut[] =
-{
-  &SaErrorType, // result (SaErrorT)
-  0
-};
-
-
-static const cMarshalType *oHpiHandlerCreateAddTEntryIn[] =
-{
-  &oHpiTextBufferType, // name
-  &oHpiTextBufferType, // value
-  0
-};
-
-static const cMarshalType *oHpiHandlerCreateAddTEntryOut[] =
-{
-  &SaErrorType, // result (SaErrorT)
-  0
-};
 
+// oHpi
 
 static const cMarshalType *oHpiHandlerCreateIn[] =
 {
-  &SaErrorType, // dummy entry
+  &oHpiHandlerConfigType, // dummy entry
   0
 };
 
@@ -1413,7 +1804,6 @@ static const cMarshalType *oHpiInjectEventOut[] =
 
 static cHpiMarshal hpi_marshal[] =
 {
-  dHpiMarshalEntry( saHpiVersionGet ),
   dHpiMarshalEntry( saHpiSessionOpen ),
   dHpiMarshalEntry( saHpiSessionClose ),
   dHpiMarshalEntry( saHpiDiscover ),
@@ -1425,7 +1815,11 @@ static cHpiMarshal hpi_marshal[] =
   dHpiMarshalEntry( saHpiResourceSeveritySet ),
   dHpiMarshalEntry( saHpiResourceTagSet ),
   dHpiMarshalEntry( saHpiResourceIdGet ),
+  dHpiMarshalEntry( saHpiGetIdByEntityPath ),
+  dHpiMarshalEntry( saHpiGetChildEntityPath ),
+  dHpiMarshalEntry( saHpiResourceFailedRemove ),
   dHpiMarshalEntry( saHpiEventLogInfoGet ),
+  dHpiMarshalEntry( saHpiEventLogCapabilitiesGet ),
   dHpiMarshalEntry( saHpiEventLogEntryGet ),
   dHpiMarshalEntry( saHpiEventLogEntryAdd ),
   dHpiMarshalEntry( saHpiEventLogClear ),
@@ -1461,9 +1855,11 @@ static cHpiMarshal hpi_marshal[] =
   dHpiMarshalEntry( saHpiIdrInfoGet ),
   dHpiMarshalEntry( saHpiIdrAreaHeaderGet ),
   dHpiMarshalEntry( saHpiIdrAreaAdd ),
+  dHpiMarshalEntry( saHpiIdrAreaAddById ),
   dHpiMarshalEntry( saHpiIdrAreaDelete ),
   dHpiMarshalEntry( saHpiIdrFieldGet ),
   dHpiMarshalEntry( saHpiIdrFieldAdd ),
+  dHpiMarshalEntry( saHpiIdrFieldAddById ),
   dHpiMarshalEntry( saHpiIdrFieldSet ),
   dHpiMarshalEntry( saHpiIdrFieldDelete ),
   dHpiMarshalEntry( saHpiWatchdogTimerGet ),
@@ -1476,6 +1872,26 @@ static cHpiMarshal hpi_marshal[] =
   dHpiMarshalEntry( saHpiAnnunciatorDelete ),
   dHpiMarshalEntry( saHpiAnnunciatorModeGet ),
   dHpiMarshalEntry( saHpiAnnunciatorModeSet ),
+  dHpiMarshalEntry( saHpiDimiInfoGet ),
+  dHpiMarshalEntry( saHpiDimiTestInfoGet ),
+  dHpiMarshalEntry( saHpiDimiTestReadinessGet ),
+  dHpiMarshalEntry( saHpiDimiTestStart ),
+  dHpiMarshalEntry( saHpiDimiTestCancel ),
+  dHpiMarshalEntry( saHpiDimiTestStatusGet ),
+  dHpiMarshalEntry( saHpiDimiTestResultsGet ),
+  dHpiMarshalEntry( saHpiFumiSourceSet ),
+  dHpiMarshalEntry( saHpiFumiSourceInfoValidateStart ),
+  dHpiMarshalEntry( saHpiFumiSourceInfoGet ),
+  dHpiMarshalEntry( saHpiFumiTargetInfoGet ),
+  dHpiMarshalEntry( saHpiFumiBackupStart ),
+  dHpiMarshalEntry( saHpiFumiBankBootOrderSet ),
+  dHpiMarshalEntry( saHpiFumiBankCopyStart ),
+  dHpiMarshalEntry( saHpiFumiInstallStart ),
+  dHpiMarshalEntry( saHpiFumiUpgradeStatusGet ),
+  dHpiMarshalEntry( saHpiFumiTargetVerifyStart ),
+  dHpiMarshalEntry( saHpiFumiUpgradeCancel ),
+  dHpiMarshalEntry( saHpiFumiRollback ),
+  dHpiMarshalEntry( saHpiFumiActivate ),
   dHpiMarshalEntry( saHpiHotSwapPolicyCancel ),
   dHpiMarshalEntry( saHpiResourceActiveSet ),
   dHpiMarshalEntry( saHpiResourceInactiveSet ),
@@ -1488,12 +1904,12 @@ static cHpiMarshal hpi_marshal[] =
   dHpiMarshalEntry( saHpiHotSwapIndicatorStateGet ),
   dHpiMarshalEntry( saHpiHotSwapIndicatorStateSet ),
   dHpiMarshalEntry( saHpiParmControl ),
+  dHpiMarshalEntry( saHpiResourceLoadIdGet ),
+  dHpiMarshalEntry( saHpiResourceLoadIdSet ),
   dHpiMarshalEntry( saHpiResourceResetStateGet ),
   dHpiMarshalEntry( saHpiResourceResetStateSet ),
   dHpiMarshalEntry( saHpiResourcePowerStateGet ),
   dHpiMarshalEntry( saHpiResourcePowerStateSet ),
-  dHpiMarshalEntry( oHpiHandlerCreateInit ),
-  dHpiMarshalEntry( oHpiHandlerCreateAddTEntry ),
   dHpiMarshalEntry( oHpiHandlerCreate ),
   dHpiMarshalEntry( oHpiHandlerDestroy ),
   dHpiMarshalEntry( oHpiHandlerInfo ),
