@@ -35,7 +35,6 @@ extern "C" {
 typedef enum
 {
   eFsaHpiNull,
-  eFsaHpiVersionGet,
   eFsaHpiSessionOpen,
   eFsaHpiSessionClose,
   eFsaHpiDiscover,
@@ -47,7 +46,11 @@ typedef enum
   eFsaHpiResourceSeveritySet,
   eFsaHpiResourceTagSet,
   eFsaHpiResourceIdGet,
+  eFsaHpiGetIdByEntityPath,
+  eFsaHpiGetChildEntityPath,
+  eFsaHpiResourceFailedRemove,
   eFsaHpiEventLogInfoGet,
+  eFsaHpiEventLogCapabilitiesGet,
   eFsaHpiEventLogEntryGet,
   eFsaHpiEventLogEntryAdd,
   eFsaHpiEventLogClear,
@@ -83,9 +86,11 @@ typedef enum
   eFsaHpiIdrInfoGet,
   eFsaHpiIdrAreaHeaderGet,
   eFsaHpiIdrAreaAdd,
+  eFsaHpiIdrAreaAddById,
   eFsaHpiIdrAreaDelete,
   eFsaHpiIdrFieldGet,
   eFsaHpiIdrFieldAdd,
+  eFsaHpiIdrFieldAddById,
   eFsaHpiIdrFieldSet,
   eFsaHpiIdrFieldDelete,
   eFsaHpiWatchdogTimerGet,
@@ -98,6 +103,26 @@ typedef enum
   eFsaHpiAnnunciatorDelete,
   eFsaHpiAnnunciatorModeGet,
   eFsaHpiAnnunciatorModeSet,
+  eFsaHpiDimiInfoGet,
+  eFsaHpiDimiTestInfoGet,
+  eFsaHpiDimiTestReadinessGet,
+  eFsaHpiDimiTestStart,
+  eFsaHpiDimiTestCancel,
+  eFsaHpiDimiTestStatusGet,
+  eFsaHpiDimiTestResultsGet,
+  eFsaHpiFumiSourceSet,
+  eFsaHpiFumiSourceInfoValidateStart,
+  eFsaHpiFumiSourceInfoGet,
+  eFsaHpiFumiTargetInfoGet,
+  eFsaHpiFumiBackupStart,
+  eFsaHpiFumiBankBootOrderSet,
+  eFsaHpiFumiBankCopyStart,
+  eFsaHpiFumiInstallStart,
+  eFsaHpiFumiUpgradeStatusGet,
+  eFsaHpiFumiTargetVerifyStart,
+  eFsaHpiFumiUpgradeCancel,
+  eFsaHpiFumiRollback,
+  eFsaHpiFumiActivate,
   eFsaHpiHotSwapPolicyCancel,
   eFsaHpiResourceActiveSet,
   eFsaHpiResourceInactiveSet,
@@ -110,12 +135,12 @@ typedef enum
   eFsaHpiHotSwapIndicatorStateGet,
   eFsaHpiHotSwapIndicatorStateSet,
   eFsaHpiParmControl,
+  eFsaHpiResourceLoadIdGet,
+  eFsaHpiResourceLoadIdSet,
   eFsaHpiResourceResetStateGet,
   eFsaHpiResourceResetStateSet,
   eFsaHpiResourcePowerStateGet,
   eFsaHpiResourcePowerStateSet,
-  eFoHpiHandlerCreateInit,
-  eFoHpiHandlerCreateAddTEntry,
   eFoHpiHandlerCreate,
   eFoHpiHandlerDestroy,
   eFoHpiHandlerInfo,
