@@ -2,6 +2,7 @@
  * marshaling/demarshaling of hpi data types
  *
  * Copyright (c) 2004 by FORCE Computers.
+ * (C) Copyright IBM Corp. 2008
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,7 +13,8 @@
  *
  * Authors:
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
- *     W. David Ashley <dashley@us.ibm.com.com>
+ *     W. David Ashley <dashley@us.ibm.com>
+ *     Renier Morales <renier@openhpi.org>
  */
 
 #ifndef dMarshalHpiTypes_h
@@ -52,7 +54,7 @@ extern "C" {
 #define SaHpiFloat32Type Marshal_Float32Type
 #define SaHpiFloat64Type Marshal_Float64Type
 
-#define SaHpiBoolType    SaHpiUint8Type
+#define SaHpiBoolType SaHpiUint8Type
 #define SaHpiManufacturerIdType SaHpiUint32Type
 #define SaHpiVersionType SaHpiUint32Type
 #define SaErrorType SaHpiInt32Type
@@ -64,6 +66,8 @@ extern "C" {
 #define SaHpiEntryIdType    SaHpiUint32Type
 #define SaHpiTimeType       SaHpiInt64Type
 #define SaHpiTimeoutType    SaHpiInt64Type
+#define SaHpiLoadNumberType SaHpiUint32Type
+#define SaHpiEventLogCapabilitiesType SaHpiUint32Type
 
 // text buffer
 #define SaHpiTextTypeType   SaHpiUint32Type
@@ -170,6 +174,43 @@ extern cMarshalType SaHpiAnnouncementType;
 #define SaHpiAnnunciatorTypeType SaHpiUint32Type
 extern cMarshalType SaHpiAnnunciatorRecType;
 
+// DIMIs
+#define SaHpiDimiNumType SaHpiUint32Type
+#define SaHpiDimiTestNumType SaHpiUint32Type
+#define SaHpiDimiTotalTestsType SaHpiUint32Type
+#define SaHpiDimiTestServiceImpactType SaHpiUint32Type
+#define SaHpiDimiTestCapabilityType SaHpiUint32Type
+#define SaHpiDimiTestServiceImpactType SaHpiUint32Type
+#define SaHpiDimiTestParamTypeType SaHpiUint32Type
+#define SaHpiDimiReadyType SaHpiUint32Type
+#define SaHpiDimiTestPercentCompletedType SaHpiUint32Type
+#define SaHpiDimiTestRunStatusType SaHpiUint32Type
+#define SaHpiDimiTestErrCodeType SaHpiUint32Type
+extern cMarshalType SaHpiDimiInfoType;
+extern cMarshalType SaHpiDimiTestParameterValueUnionType;
+extern cMarshalType SaHpiDimiTestParamValue1Type;
+extern cMarshalType SaHpiDimiTestParamValue2Type;
+extern cMarshalType SaHpiDimiTestParamsDefinitionType;
+extern cMarshalType SaHpiDimiTestAffectedEntityType;
+extern cMarshalType SaHpiDimiTestType;
+extern cMarshalType SaHpiDimiTestResultsType;
+typedef struct {
+        SaHpiUint8T NumberOfParams;
+        SaHpiDimiTestVariableParamsT *ParamsList;
+} SaHpiDimiTestVariableParamsListT;
+extern cMarshalType SaHpiDimiTestVariableParamsType;
+extern cMarshalType SaHpiDimiTestVariableParamsListType;
+
+// FUMIs
+#define SaHpiFumiNumType SaHpiUint32Type
+#define SaHpiBankNumType SaHpiUint8Type
+#define SaHpiFumiProtocolType SaHpiUint32Type
+#define SaHpiFumiCapabilityType SaHpiUint32Type
+#define SaHpiFumiUpgradeStatusType SaHpiUint32Type
+#define SaHpiFumiSourceStatusType SaHpiUint32Type
+#define SaHpiFumiBankStateType SaHpiUint32Type
+extern cMarshalType SaHpiFumiSourceInfoType;
+extern cMarshalType SaHpiFumiBankInfoType;
 
 // resource data record
 #define SaHpiRdrTypeType SaHpiUint32Type
@@ -190,6 +231,7 @@ extern cMarshalType SaHpiDomainEventType;
 extern cMarshalType SaHpiSensorEventType;
 #define SaHpiSensorEnableOptDataType SaHpiUint8Type
 extern cMarshalType SaHpiSensorEnableChangeEventType;
+#define SaHpiHsCauseOfStateChangeType SaHpiUint32Type
 extern cMarshalType SaHpiHotSwapEventType;
 extern cMarshalType SaHpiWatchdogEventType;
 #define SaHpiSwEventTypeType SaHpiUint32Type
@@ -220,6 +262,7 @@ extern cMarshalType SaHpiResourceInfoType;
 
 // rpt entry
 extern cMarshalType SaHpiRptEntryType;
+extern cMarshalType SaHpiLoadIdType;
 
 // domains
 #define SaHpiDomainCapabilitiesType SaHpiUint32Type
@@ -234,12 +277,21 @@ extern cMarshalType SaHpiEventLogInfoType;
 #define SaHpiEventLogEntryIdType SaHpiUint32Type
 extern cMarshalType SaHpiEventLogEntryType;
 
+
 //----------------------------------------------------------------------------
 // The following support the oHpi dynamic configuration APIs
 //----------------------------------------------------------------------------
 
-// plugin stuff
-#define refcountType SaHpiInt32Type
+typedef struct {
+	SaHpiUint8T Name[SAHPI_MAX_TEXT_BUFFER_LENGTH];
+	SaHpiUint8T Value[SAHPI_MAX_TEXT_BUFFER_LENGTH];
+} oHpiHandlerConfigParamT;
+extern cMarshalType oHpiHandlerConfigParamType;
+typedef struct {
+	SaHpiUint8T NumberOfParams;
+	oHpiHandlerConfigParamT *Params;
+} oHpiHandlerConfigT;
+extern cMarshalType oHpiHandlerConfigType;
 
 // handler stuff
 #define oHpiHandlerIdType SaHpiUint32Type
@@ -247,19 +299,6 @@ extern cMarshalType oHpiHandlerInfoType;
 #define oHpiGlobalParamTypeType SaHpiUint32Type
 extern cMarshalType oHpiGlobalParamType;
 
-typedef struct {
-        SaHpiUint16T   DataLength;
-        SaHpiUint8T    Data[OH_MAX_TEXT_BUFFER_LENGTH];  /* Data buffer */
-} oHpiTextBufferT;
-
-extern cMarshalType oHpiTextBufferType;
-
-
-
-
-
-
-
 #ifdef __cplusplus
 }
 #endif
