@@ -10,7 +10,7 @@
  * full licensing terms.
  *
  * Author(s):
- *      Renier Morales <renierm@users.sf.net>
+ *      Renier Morales <renier@openhpi.org>
  *      Steve Sherman <stevees@us.ibm.com>
  */
 
@@ -28,7 +28,7 @@
  *
  * Return values:
  * Builds/updates internal RPT cache - normal operation.
- * SA_ERR_HPI_OUT_OF_SPACE - Cannot allocate space for internal memory
+ * SA_ERR_HPI_OUT_OF_MEMORY - Cannot allocate space for internal memory
  **/
 SaErrorT snmp_bc_discover_resources(void *hnd)
 {
@@ -41,7 +41,7 @@ SaErrorT snmp_bc_discover_resources(void *hnd)
         struct snmp_bc_hnd *custom_handle;
 	
 	if (!hnd) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}		
 			
@@ -51,7 +51,7 @@ SaErrorT snmp_bc_discover_resources(void *hnd)
 	custom_handle = (struct snmp_bc_hnd *)handle->data;
 	
         if (!custom_handle) {
-                dbg("Invalid parameter.");
+                err("Invalid parameter.");
                 return(SA_ERR_HPI_INVALID_PARAMS);
         }
 
@@ -60,13 +60,13 @@ SaErrorT snmp_bc_discover_resources(void *hnd)
 	/* Find root Entity Path */
 	root_tuple = (char *)g_hash_table_lookup(handle->config, "entity_root");
         if (root_tuple == NULL) {
-                dbg("Cannot find configuration parameter.");
+                err("Cannot find configuration parameter.");
                 snmp_bc_unlock_handler(custom_handle);
                 return(SA_ERR_HPI_INTERNAL_ERROR);
         }
         err = oh_encode_entitypath(root_tuple, &ep_root);
         if (err) {
-                dbg("Cannot convert entity path to string. Error=%s.", oh_lookup_error(err));
+                err("Cannot convert entity path to string. Error=%s.", oh_lookup_error(err));
                 snmp_bc_unlock_handler(custom_handle);
                 return(SA_ERR_HPI_INTERNAL_ERROR);
         }
@@ -76,9 +76,9 @@ SaErrorT snmp_bc_discover_resources(void *hnd)
 	/* Allocate space for temporary RPT cache                          */
         /*custom_handle->tmpcache = (RPTable *)g_malloc0(sizeof(RPTable)); */
         /*if (custom_handle->tmpcache == NULL) {                           */
-        /*        dbg("Out of memory.");                                   */
+        /*        err("Out of memory.");                                   */
         /*        snmp_bc_unlock_handler(custom_handle);                   */
-        /*        return(SA_ERR_HPI_OUT_OF_SPACE);                         */
+        /*        return(SA_ERR_HPI_OUT_OF_MEMORY);                         */
 	/*}                                                                */
 	/*                                                                 */
 	/* Initialize tmpqueue                                             */
@@ -102,7 +102,7 @@ SaErrorT snmp_bc_discover_resources(void *hnd)
 			 */
 			err = SA_OK;
 		} else {
-			dbg("Discovery failed. Error=%s.", oh_lookup_error(err));
+			err("Discovery failed. Error=%s.", oh_lookup_error(err));
 		}
 		goto CLEANUP;
 	}
@@ -127,7 +127,7 @@ SaErrorT snmp_bc_discover_resources(void *hnd)
 		/* only log the error.  Do not do any recovery because log entries */
 		/* are still kept in bc mm.  We'll pick them up during synch.      */
 		/* --------------------------------------------------------------- */
-		trace("snmp_bc_discover, Error %s when building elcache.\n", oh_lookup_error(err1));
+		dbg("snmp_bc_discover, Error %s when building elcache.\n", oh_lookup_error(err1));
 	}
 	
 	if (custom_handle->isFirstDiscovery == SAHPI_TRUE)
@@ -149,7 +149,7 @@ SaErrorT snmp_bc_discover_resources(void *hnd)
  *
  * Return values:
  * Adds sensor RDRs to internal Infra-structure queues - normal case
- * SA_ERR_HPI_OUT_OF_SPACE - Cannot allocate space for internal memory
+ * SA_ERR_HPI_OUT_OF_MEMORY - Cannot allocate space for internal memory
  **/
 SaErrorT snmp_bc_discover_sensors(struct oh_handler_state *handle,
 				  struct snmp_bc_sensor *sensor_array,
@@ -167,8 +167,8 @@ SaErrorT snmp_bc_discover_sensors(struct oh_handler_state *handle,
 	for (i=0; sensor_array[i].index != 0; i++) {
 		rdrptr = (SaHpiRdrT *)g_malloc0(sizeof(SaHpiRdrT));
 		if (rdrptr == NULL) {
-			dbg("Out of memory.");
-			return(SA_ERR_HPI_OUT_OF_SPACE);
+			err("Out of memory.");
+			return(SA_ERR_HPI_OUT_OF_MEMORY);
 		}
 
 		valid_sensor = SAHPI_FALSE;
@@ -186,7 +186,7 @@ SaErrorT snmp_bc_discover_sensors(struct oh_handler_state *handle,
 							  sensor_array[i].sensor_info.mib.write_only);
 			}
 			else {
-				dbg("Sensor %s cannot be read.", sensor_array[i].comment);
+				err("Sensor %s cannot be read.", sensor_array[i].comment);
 				g_free(rdrptr);
 				return(SA_ERR_HPI_INTERNAL_ERROR);
 			}
@@ -202,7 +202,7 @@ SaErrorT snmp_bc_discover_sensors(struct oh_handler_state *handle,
 			oh_init_textbuffer(&(rdrptr->IdString));
 			oh_append_textbuffer(&(rdrptr->IdString), sensor_array[i].comment);
 
-			trace("Discovered sensor: %s.", rdrptr->IdString.Data);
+			dbg("Discovered sensor: %s.", rdrptr->IdString.Data);
 
 			sensor_info_ptr = g_memdup(&(sensor_array[i].sensor_info), sizeof(struct SensorInfo));
 			err = oh_add_rdr(handle->rptcache,
@@ -210,7 +210,7 @@ SaErrorT snmp_bc_discover_sensors(struct oh_handler_state *handle,
 					 rdrptr,
 					 sensor_info_ptr, 0);
 			if (err) {
-				dbg("Cannot add RDR. Error=%s.", oh_lookup_error(err));
+				err("Cannot add RDR. Error=%s.", oh_lookup_error(err));
 				g_free(rdrptr);
 			}
 			else {
@@ -239,7 +239,7 @@ SaErrorT snmp_bc_discover_sensors(struct oh_handler_state *handle,
  *
  * Return values:
  * Adds control RDRs to internal Infra-structure queues - normal case
- * SA_ERR_HPI_OUT_OF_SPACE - Cannot allocate space for internal memory
+ * SA_ERR_HPI_OUT_OF_MEMORY - Cannot allocate space for internal memory
   **/
 SaErrorT snmp_bc_discover_controls(struct oh_handler_state *handle,
 				   struct snmp_bc_control *control_array,
@@ -257,8 +257,8 @@ SaErrorT snmp_bc_discover_controls(struct oh_handler_state *handle,
 	for (i=0; control_array[i].index != 0; i++) {
 		rdrptr = (SaHpiRdrT *)g_malloc0(sizeof(SaHpiRdrT));
 		if (rdrptr == NULL) {
-			dbg("Out of memory.");
-			return(SA_ERR_HPI_OUT_OF_SPACE);
+			err("Out of memory.");
+			return(SA_ERR_HPI_OUT_OF_MEMORY);
 		}
 
 		valid_control = rdr_exists(custom_handle,
@@ -277,7 +277,7 @@ SaErrorT snmp_bc_discover_controls(struct oh_handler_state *handle,
 			oh_init_textbuffer(&(rdrptr->IdString));
 			oh_append_textbuffer(&(rdrptr->IdString), control_array[i].comment);
 
-			trace("Discovered control: %s.", rdrptr->IdString.Data);
+			dbg("Discovered control: %s.", rdrptr->IdString.Data);
 
 			control_info_ptr = g_memdup(&(control_array[i].control_info), sizeof(struct ControlInfo));
 			err = oh_add_rdr(handle->rptcache,
@@ -285,7 +285,7 @@ SaErrorT snmp_bc_discover_controls(struct oh_handler_state *handle,
 					 rdrptr,
 					 control_info_ptr, 0);
 			if (err) {
-				dbg("Cannot add RDR. Error=%s.", oh_lookup_error(err));
+				err("Cannot add RDR. Error=%s.", oh_lookup_error(err));
 				g_free(rdrptr);
 			}
 			else {
@@ -310,7 +310,7 @@ SaErrorT snmp_bc_discover_controls(struct oh_handler_state *handle,
  *
  * Return values:
  * Adds inventory RDRs to internal Infra-structure queues - normal case
- * SA_ERR_HPI_OUT_OF_SPACE - Cannot allocate space for internal memory
+ * SA_ERR_HPI_OUT_OF_MEMORY - Cannot allocate space for internal memory
   **/
 SaErrorT snmp_bc_discover_inventories(struct oh_handler_state *handle,
 				      struct snmp_bc_inventory *inventory_array,
@@ -326,18 +326,18 @@ SaErrorT snmp_bc_discover_inventories(struct oh_handler_state *handle,
 	custom_handle = (struct snmp_bc_hnd *)handle->data;
 
 	/* Assumming OidManufacturer is defined and determines readable of other VPD */
-	for (i=0; inventory_array[i].inventory_info.mib.oid.OidManufacturer != NULL; i++) {
+	for (i=0; inventory_array[i].inventory_info.hardware_mib.oid.OidManufacturer != NULL; i++) {
 		rdrptr = (SaHpiRdrT *)g_malloc0(sizeof(SaHpiRdrT));
 		if (rdrptr == NULL) {
-			dbg("Out of memory.");
-			return(SA_ERR_HPI_OUT_OF_SPACE);
+			err("Out of memory.");
+			return(SA_ERR_HPI_OUT_OF_MEMORY);
 		}
 		
 		valid_idr = rdr_exists(custom_handle,
 				       &(res_oh_event->resource.ResourceEntity), 0,
-				       inventory_array[i].inventory_info.mib.oid.OidManufacturer,
+				       inventory_array[i].inventory_info.hardware_mib.oid.OidManufacturer,
 				       0, 0);
-
+	
 		/* Add inventory RDR, if inventory can be read */
 		if (valid_idr) {
 			rdrptr->RdrType = SAHPI_INVENTORY_RDR;
@@ -347,7 +347,7 @@ SaErrorT snmp_bc_discover_inventories(struct oh_handler_state *handle,
 			oh_init_textbuffer(&(rdrptr->IdString));
 			oh_append_textbuffer(&(rdrptr->IdString), inventory_array[i].comment);
 
-			trace("Discovered inventory: %s.", rdrptr->IdString.Data);
+			dbg("Discovered inventory: %s.", rdrptr->IdString.Data);
 
 			inventory_info_ptr = g_memdup(&(inventory_array[i].inventory_info), sizeof(struct InventoryInfo));
 			err = oh_add_rdr(handle->rptcache,
@@ -355,7 +355,7 @@ SaErrorT snmp_bc_discover_inventories(struct oh_handler_state *handle,
 					 rdrptr,
 					 inventory_info_ptr, 0);
 			if (err) {
-				dbg("Cannot add RDR. Error=%s.", oh_lookup_error(err));
+				err("Cannot add RDR. Error=%s.", oh_lookup_error(err));
 				g_free(rdrptr);
 			}
 			else {
@@ -383,7 +383,7 @@ SaErrorT snmp_bc_discover_inventories(struct oh_handler_state *handle,
  * Return values:
  * SaHpiTextBufferT - normal operation.
  * SA_ERR_HPI_INVALID_PARAMS - @buffer is NULL; or @loc not valid
- * SA_ERR_HPI_OUT_OF_SPACE - Cannot allocate space for internal memory.
+ * SA_ERR_HPI_OUT_OF_MEMORY - Cannot allocate space for internal memory.
  **/
 SaErrorT snmp_bc_create_resourcetag(SaHpiTextBufferT *buffer, const char *str, SaHpiEntityLocationT loc)
 {
@@ -404,8 +404,8 @@ SaErrorT snmp_bc_create_resourcetag(SaHpiTextBufferT *buffer, const char *str, S
 
 		locstr = (gchar *)g_malloc0(OH_MAX_LOCATION_DIGITS + 1);
 		if (locstr == NULL) {
-			dbg("Out of memory.");
-			return(SA_ERR_HPI_OUT_OF_SPACE);
+			err("Out of memory.");
+			return(SA_ERR_HPI_OUT_OF_MEMORY);
 		}
 		if (loc != SNMP_BC_NOT_VALID) {
 			snprintf(locstr, OH_MAX_LOCATION_DIGITS + 1, " %d", loc);
@@ -449,6 +449,7 @@ SaHpiBoolT rdr_exists(struct snmp_bc_hnd *custom_handle,
 	if (write_only == SAHPI_TRUE) { return(SAHPI_FALSE); }; /* Can't check it if its non-readable */
 
         err = snmp_bc_oid_snmp_get(custom_handle, ep, loc_offset, oidstr, &get_value, SAHPI_TRUE);
+	
         if (err || (get_value.type == ASN_INTEGER && na && na == get_value.integer)) {
 		return(SAHPI_FALSE);
         }
@@ -476,7 +477,7 @@ SaErrorT snmp_bc_validate_ep(SaHpiEntityPathT *org_ep, SaHpiEntityPathT *val_ep)
         int i, j;
 
         if (!org_ep || !val_ep) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 
@@ -526,7 +527,7 @@ SaErrorT snmp_bc_mod_sensor_ep(SaHpiRdrT *rdrptr,
 	sensor_array_ipmi = (struct snmp_bc_ipmi_sensor *)sensor_array_in;
 
         if (!rdrptr || !sensor_array) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);
 	}
 	
@@ -551,7 +552,7 @@ SaErrorT snmp_bc_mod_sensor_ep(SaHpiRdrT *rdrptr,
 		}
 	
 	} else {
-		trace("This not one of the Blade sensor.\n");
+		dbg("This not one of the Blade sensor.\n");
 	}
 	
 	return(SA_OK);	  
@@ -577,7 +578,7 @@ SaErrorT snmp_bc_add_ep(SaHpiRdrT *rdrptr, SaHpiEntityPathT *ep_add)
 	int i;
 	
 	if ( !rdrptr || !ep_add) {
-		dbg("Invalid parameter.");
+		err("Invalid parameter.");
 		return(SA_ERR_HPI_INVALID_PARAMS);	
 	}
 	
