@@ -15,7 +15,7 @@
  *     Louis Zhuang <louis.zhuang@linux.intel.com>
  *     David Judkovics <djudkovi@us.ibm.com>
  *     Thomas Kangieser <Thomas.Kanngieser@fci.com>
- *     Renier Morales <renierm@users.sf.net>
+ *     Renier Morales <renier@openhpi.org>
  */
 
 #include <string.h>
@@ -23,6 +23,7 @@
 #include <unistd.h>
 #include <oh_config.h>
 #include <oh_plugin.h>
+#include <oh_domain.h>
 #include <oh_error.h>
 #include <oh_lock.h>
 #include <config.h>
@@ -39,9 +40,6 @@ static const char *known_globals[] = {
         "OPENHPI_DAT_SIZE_LIMIT",
         "OPENHPI_DAT_USER_LIMIT",
         "OPENHPI_DAT_SAVE",
-        //"OPENHPI_DEBUG",
-        //"OPENHPI_DEBUG_TRACE",
-        //"OPENHPI_DEBUG_LOCK",
         "OPENHPI_PATH",
         "OPENHPI_VARPATH",
         "OPENHPI_CONF",
@@ -57,9 +55,6 @@ static struct {
         SaHpiUint32T dat_size_limit;
         SaHpiUint32T dat_user_limit;
         SaHpiBoolT dat_save;
-        //unsigned char dbg;
-        //unsigned char dbg_trace;
-        //unsigned char dbg_lock;
         char path[OH_MAX_TEXT_BUFFER_LENGTH];
         char varpath[OH_MAX_TEXT_BUFFER_LENGTH];
         char conf[OH_MAX_TEXT_BUFFER_LENGTH];
@@ -74,9 +69,6 @@ static struct {
         .dat_size_limit = 0, /* Unlimited size */
         .dat_user_limit = 0, /* Unlimited size */
         .dat_save = SAHPI_FALSE,
-        //.dbg = 0,
-        //.dbg_trace = 0,
-        //.dbg_lock = 0,
         .path = OH_PLUGIN_PATH,
         .varpath = VARPATH,
         .conf = OH_DEFAULT_CONF,
@@ -84,17 +76,16 @@ static struct {
         .lock = G_STATIC_REC_MUTEX_INIT
 };
 
-/*
- * List of plugin names specified in configuration file.
- */
-static GSList *plugin_names = NULL;
-
 /*
  *  List of handler configs (parameter tables).  This list is
  *  populated during config file parse, and used to build the handler_table
  */
 static GSList *handler_configs = NULL;
 
+
+/* List of domain configurations. Domains are later created from this list. */
+static GSList *domain_configs = NULL;
+
 /*******************************************************************************
  *  In order to use the glib lexical parser we need to define token
  *  types which we want to switch on
@@ -102,7 +93,7 @@ static GSList *handler_configs = NULL;
 
 enum {
         HPI_CONF_TOKEN_HANDLER = G_TOKEN_LAST,
-        HPI_CONF_TOKEN_PLUGIN
+        HPI_CONF_TOKEN_DOMAIN
 } hpiConfType;
 
 struct tokens {
@@ -116,8 +107,8 @@ static struct tokens oh_conf_tokens[] = {
                 .token = HPI_CONF_TOKEN_HANDLER
         },
         {
-                .name = "plugin",
-                .token = HPI_CONF_TOKEN_PLUGIN
+                .name = "domain",
+                .token = HPI_CONF_TOKEN_DOMAIN
         }
 
 };
@@ -173,67 +164,6 @@ static GScannerConfig oh_scanner_config =
                 FALSE                   /* scope_0_fallback */,
         };
 
-static int seen_plugin(char *plugin_name)
-{
-        int seen = 0;
-        GSList *node = NULL;
-
-        for (node = plugin_names; node; node = node->next) {
-                char *p_name = (char *)node->data;
-                if (strcmp(plugin_name, p_name) == 0) {
-                        seen = 1;
-                        break;
-                }
-        }
-
-        return seen;
-}
-
-/**
- * process_plugin_token:
- * @oh_scanner:
- *
- *
- *
- * Return value:
- **/
-static int process_plugin_token (GScanner *oh_scanner)
-{
-        guint my_token;
-        int seen = 0;
-
-        data_access_lock();
-
-        my_token = g_scanner_get_next_token(oh_scanner);
-        if (my_token != HPI_CONF_TOKEN_PLUGIN) {
-                dbg("Token is not what I was promissed");
-                data_access_unlock();
-                return -1;
-        }
-        my_token = g_scanner_get_next_token(oh_scanner);
-        if (my_token != G_TOKEN_STRING) {
-                dbg("Where the heck is my string!");
-                data_access_unlock();
-                return -1;
-        }
-
-        seen = seen_plugin(oh_scanner->value.v_string);
-
-        if (!seen) {
-                plugin_names = g_slist_append(
-                        plugin_names,
-                        (gpointer) g_strdup(oh_scanner->value.v_string)
-                        );
-        } else {
-                dbg("Plugin name %s was found more than once. Ignoring.",
-                    oh_scanner->value.v_string);
-        }
-
-        data_access_unlock();
-
-        return 0;
-}
-
 static void process_global_param(const char *name, char *value)
 {
         if (!strcmp("OPENHPI_ON_EP", name)) {
@@ -266,24 +196,6 @@ static void process_global_param(const char *name, char *value)
                 } else {
                         global_params.dat_save = SAHPI_FALSE;
                 }
-        //} else if (!strcmp("OPENHPI_DEBUG", name)) {
-        //        if (!strcmp("YES", value)) {
-        //                global_params.dbg = 1;
-        //       } else {
-        //                global_params.dbg = 0;
-        //        }
-        //} else if (!strcmp("OPENHPI_DEBUG_TRACE", name)) {
-        //        if (!strcmp("YES", value)) {
-        //               global_params.dbg_trace = 1;
-        //        } else {
-        //                global_params.dbg_trace = 0;
-        //        }
-        //} else if (!strcmp("OPENHPI_DEBUG_LOCK", name)) {
-        //        if (!strcmp("YES", value)) {
-        //               global_params.dbg_lock = 1;
-        //        } else {
-        //                global_params.dbg_lock = 0;
-        //        }
         } else if (!strcmp("OPENHPI_PATH", name)) {
                 g_static_rec_mutex_lock(&global_params.lock);
                 memset(global_params.path, 0, OH_MAX_TEXT_BUFFER_LENGTH);
@@ -300,7 +212,7 @@ static void process_global_param(const char *name, char *value)
                 strncpy(global_params.conf, value, OH_MAX_TEXT_BUFFER_LENGTH-1);
                 g_static_rec_mutex_unlock(&global_params.lock);
         } else {
-                dbg("ERROR. Invalid global parameter %s in config file", name);
+                err("ERROR. Invalid global parameter %s in config file", name);
         }
 
         return;
@@ -343,56 +255,45 @@ static int process_handler_token (GScanner* oh_scanner)
         data_access_lock();
 
         if (g_scanner_get_next_token(oh_scanner) != HPI_CONF_TOKEN_HANDLER) {
-                dbg("Processing handler: Unexpected token.");
+                err("Processing handler: Unexpected token.");
                 data_access_unlock();
                 return -1;
         }
 
         /* Get the plugin type and store in Hash Table */
         if (g_scanner_get_next_token(oh_scanner) != G_TOKEN_STRING) {
-                dbg("Processing handler: Expected string token.");
+                err("Processing handler: Expected string token.");
                 data_access_unlock();
                 return -1;
         } else {
                 handler_stanza = g_hash_table_new_full(g_str_hash, g_str_equal,
                                                        g_free, g_free);
                 tablekey = g_strdup("plugin");
-                if (!tablekey) {
-                        dbg("Processing handler: Unable to allocate memory");
-                        goto free_table;
-                }
                 tablevalue = g_strdup(oh_scanner->value.v_string);
-                if (!tablevalue) {
-                        dbg("Processing handler: Unable to allocate memory");
-                        goto free_table_and_key;
-                }
                 g_hash_table_insert(handler_stanza,
                                     (gpointer) tablekey,
                                     (gpointer) tablevalue);
+                oh_load_plugin(tablevalue);
         }
 
         /* Check for Left Brace token type. If we have it, then continue parsing. */
         if (g_scanner_get_next_token(oh_scanner) != G_TOKEN_LEFT_CURLY) {
-                dbg("Processing handler: Expected left curly token.");
+                err("Processing handler: Expected left curly token.");
                 goto free_table;
         }
 
         while (!found_right_curly) {
                 /* get key token in key\value pair set (e.g. key = value) */
                 if (g_scanner_get_next_token(oh_scanner) != G_TOKEN_STRING) {
-                        dbg("Processing handler: Expected string token.");
+                        err("Processing handler: Expected string token.");
                         goto free_table;
                 } else {
                         tablekey = g_strdup(oh_scanner->value.v_string);
-                        if (!tablekey) {
-                                dbg("Processing handler: Unable to allocate memory");
-                                goto free_table;
-                        }
                 }
 
                 /* Check for the equal sign next. If we have it, continue parsing */
                 if (g_scanner_get_next_token(oh_scanner) != G_TOKEN_EQUAL_SIGN) {
-                        dbg("Processing handler: Expected equal sign token.");
+                        err("Processing handler: Expected equal sign token.");
                         goto free_table_and_key;
                 }
 
@@ -403,21 +304,21 @@ static int process_handler_token (GScanner* oh_scanner)
                 if (g_scanner_peek_next_token(oh_scanner) != G_TOKEN_INT &&
                     g_scanner_peek_next_token(oh_scanner) != G_TOKEN_FLOAT &&
                     g_scanner_peek_next_token(oh_scanner) != G_TOKEN_STRING) {
-                        dbg("Processing handler: Expected string, integer, or float token.");
+                        err("Processing handler: Expected string, integer, or float token.");
                         goto free_table_and_key;
                 } else { /* The type of token tells us how to fetch the value from oh_scanner */
-                        gpointer value;
+                        gpointer value = NULL;
                         int current_token = g_scanner_get_next_token(oh_scanner);
 
                         if (current_token == G_TOKEN_INT) {
                                 gulong *value_int =
                                         (gulong *)g_malloc(sizeof(gulong));
-                                if (value_int != NULL) *value_int = oh_scanner->value.v_int;
+                                *value_int = oh_scanner->value.v_int;
                                 value = (gpointer)value_int;
                         } else if (current_token == G_TOKEN_FLOAT) {
                                 gdouble *value_float =
                                         (gdouble *)g_malloc(sizeof(gdouble));
-                                if (value_float != NULL) *value_float = oh_scanner->value.v_float;
+                                *value_float = oh_scanner->value.v_float;
                                 value = (gpointer)value_float;
                         } else {
                                 gchar *value_string =
@@ -426,7 +327,7 @@ static int process_handler_token (GScanner* oh_scanner)
                         }
 
                         if (value == NULL) {
-                                dbg("Processing handler:"
+                                err("Processing handler:"
                                     " Unable to allocate memory for value."
                                     " Token Type: %d",
                                     current_token);
@@ -479,26 +380,26 @@ static int process_global_token(GScanner *scanner)
         /* Get the global parameter name */
         current_token = g_scanner_get_next_token(scanner);
         if (current_token != G_TOKEN_STRING) {
-                dbg("Processing global: Expected string token. Got %d",
+                err("Processing global: Expected string token. Got %d",
                     current_token);
                 goto quit;
         }
 
         name = g_strdup(scanner->value.v_string);
         if (!name) {
-                dbg("Unable to allocate for global param name.");
+                err("Unable to allocate for global param name.");
                 goto quit;
         }
 
         current_token = g_scanner_get_next_token(scanner);
         if (current_token != G_TOKEN_EQUAL_SIGN) {
-                dbg("Did not get expected '=' token. Got %d", current_token);
+                err("Did not get expected '=' token. Got %d", current_token);
                 goto free_and_quit;
         }
 
         current_token = g_scanner_get_next_token(scanner);
         if (current_token != G_TOKEN_STRING && current_token != G_TOKEN_INT) {
-                dbg("Did not get expected string value for global parameter."
+                err("Did not get expected string value for global parameter."
                     " Got %d", current_token);
                 goto free_and_quit;
         }
@@ -518,7 +419,7 @@ static int process_global_token(GScanner *scanner)
         }
 
         if (!value) {
-                dbg("Unable to allocate for global param value.");
+                err("Unable to allocate for global param value.");
                 goto free_and_quit;
         }
 
@@ -535,6 +436,171 @@ quit:
         return -1;
 }
 
+/**
+ * process_domain_token
+ * @scanner: Object parser
+ * 
+ * Returns: 0 on success.
+ **/
+static int process_domain_token(GScanner *scanner)
+{
+	GHashTable *domain_stanza = NULL;
+        char *tablekey, *tablevalue;
+        int found_right_curly = 0;
+        int v_signed = 0;
+
+        data_access_lock();
+
+        if (g_scanner_get_next_token(scanner) != HPI_CONF_TOKEN_DOMAIN) {
+                err("Processing domain: Unexpected token.");
+                data_access_unlock();
+                return -1;
+        }
+
+        /* Get the domain id and store in Hash Table */
+        if (g_scanner_get_next_token(scanner) != G_TOKEN_INT) {
+                err("Processing handler: Expected domain id.");
+                data_access_unlock();
+                return -1;
+        } else {
+                if ((SaHpiDomainIdT)scanner->value.v_int == SAHPI_UNSPECIFIED_DOMAIN_ID) {
+                        err("Processing domain: value for id cannot be SAHPI_UNSPECIFIED_DOMAIN_ID (4294967295).");
+                        return -1;
+                }
+                SaHpiDomainIdT *id = (SaHpiDomainIdT *)g_malloc0(sizeof(SaHpiDomainIdT));
+                *id = (SaHpiDomainIdT)scanner->value.v_int;
+                domain_stanza = g_hash_table_new_full(g_str_hash, g_str_equal,
+                                                      g_free, g_free);
+                tablekey = g_strdup("id");
+                tablevalue = (gpointer)id;
+                g_hash_table_insert(domain_stanza,
+                                    (gpointer)tablekey,
+                                    (gpointer)tablevalue);
+        }
+
+        /* Check for Left Brace token type. If we have it, then continue parsing. */
+        if (g_scanner_get_next_token(scanner) != G_TOKEN_LEFT_CURLY) {
+                err("Processing domain: Expected left curly token.");
+                goto free_table;
+        }
+
+        while (!found_right_curly) {
+                int current_token;
+                /* get key token in key\value pair set (e.g. key = value) */
+                if (g_scanner_get_next_token(scanner) != G_TOKEN_STRING) {
+                        err("Processing domain: Expected string token.");
+                        goto free_table;
+                } else {
+                        tablekey = g_strdup(scanner->value.v_string);
+                }
+
+                /* Check for the equal sign next. If we have it, continue parsing */
+                if (g_scanner_get_next_token(scanner) != G_TOKEN_EQUAL_SIGN) {
+                        err("Processing domain: Expected equal sign token.");
+                        goto free_table_and_key;
+                }
+
+                /*
+                 * Now check for the value token in the key\value set.
+                 * Store the key\value value pair in the hash table and continue on.
+                 */
+                current_token = g_scanner_get_next_token(scanner);
+                if (strcmp("entity_pattern", tablekey) == 0 || /* Required */
+                    strcmp("tag", tablekey) == 0) { /* Optional */
+                        if (current_token != G_TOKEN_STRING) {
+                                err("Processing domain: value for %s is not a string!", tablekey);
+                                goto free_table_and_key;
+                        }
+                } else if (strcmp("child_of", tablekey) == 0 || /* Optional. 0 means default domain. */
+                           strcmp("peer_of", tablekey) == 0 || /* Optional. 0 means default domain. */
+                           strcmp("ai_readonly", tablekey) == 0) { /* Optional. 1 (default) means yes, 0 means no */
+                        if (current_token != G_TOKEN_INT) {
+                                err("Processing domain: value for %s is not a valid integer!", tablekey);
+                                goto free_table_and_key;
+                        }
+                } else if (strcmp("ai_timeout", tablekey) == 0) { /* Optional. 0 (default) is IMMEDIATE. -1 is BLOCK. In seconds. */
+                        if (current_token == '-') {
+                            v_signed = 1;
+                            current_token = g_scanner_get_next_token(scanner);
+                        }
+
+                        if (current_token != G_TOKEN_INT &&
+                            current_token != G_TOKEN_FLOAT) {
+                                err("Processing domain: Invalid value for %s!", tablekey);
+                                goto free_table_and_key;
+                        }
+                } else {
+                        dbg("Dropping unknown name/value pair. going on to next.");
+                        g_free(tablekey);
+                        goto find_right_curly;
+                }
+
+                /* The type of token tells us how to fetch the value from scanner */
+                gpointer value = NULL;
+                if (current_token == G_TOKEN_INT) {
+                        gulong *value_int =
+                                (gulong *)g_malloc(sizeof(gulong));
+                        *value_int = (gulong)scanner->value.v_int;
+                        if (v_signed) {
+                                *value_int = -(*value_int);
+                                v_signed = 0;
+                        }
+                        value = (gpointer)value_int;
+                } else if (current_token == G_TOKEN_FLOAT) {
+                        gdouble *value_double =
+                                (gdouble *)g_malloc(sizeof(gdouble));
+                        *value_double = (gdouble)scanner->value.v_float;
+                        value = (gpointer)value_double;
+                } else if (current_token == G_TOKEN_STRING) {
+                        gchar *value_string =
+                                        g_strdup(scanner->value.v_string);
+                        value = (gpointer)value_string;
+                }
+
+                if (!value) {
+                        err("Processing domain:"
+                            " Unable to extract value."
+                            " Token Type: %d",
+                            current_token);
+                        goto free_table_and_key;
+                } else {
+                        g_hash_table_insert(domain_stanza,
+                                            (gpointer)tablekey,
+                                            value);
+                }
+                
+find_right_curly:
+                if (g_scanner_peek_next_token(scanner) == G_TOKEN_RIGHT_CURLY) {
+                        g_scanner_get_next_token(scanner);
+                        found_right_curly = 1;
+                }
+        } /* end of while(!found_right_curly) */
+
+        /* Attach table describing handler stanza to the global linked list of handlers */
+        if (domain_stanza != NULL) {
+                domain_configs = g_slist_append(
+                        domain_configs,
+                        (gpointer)domain_stanza);
+        }
+
+        data_access_unlock();
+
+        return 0;
+
+free_table_and_key:
+        g_free(tablekey);
+free_table:
+        /**
+        There was an error reading a token so we need to error out,
+        but not before cleaning up. Destroy the table.
+        */
+        g_hash_table_destroy(domain_stanza);
+
+        data_access_unlock();
+
+        return -1;
+}
+
 /**
  * scanner_msg_handler: a reference of this function is passed into the GScanner.
  * Used by the GScanner object to output messages that come up during parsing.
@@ -549,9 +615,9 @@ static void scanner_msg_handler (GScanner *scanner, gchar *message, gboolean is_
 {
         g_return_if_fail (scanner != NULL);
 
-        dbg("%s:%d: %s%s\n",
-                scanner->input_name ? scanner->input_name : "<memory>",
-                scanner->line, is_error ? "error: " : "", message );
+        err("%s:%d: %s%s\n",
+            scanner->input_name ? scanner->input_name : "<memory>",
+            scanner->line, is_error ? "error: " : "", message );
 }
 
 /**
@@ -572,15 +638,14 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
         int num_tokens = sizeof(oh_conf_tokens) / sizeof(oh_conf_tokens[0]);
 
         if (!filename || !config) {
-                dbg("Error. Invalid parameters");
+                err("Error. Invalid parameters");
                 return -1;
         }
 
-        plugin_names = NULL;
         handler_configs = NULL;
         oh_scanner = g_scanner_new(&oh_scanner_config);
         if (!oh_scanner) {
-                dbg("Couldn't allocate g_scanner for file parsing");
+                err("Couldn't allocate g_scanner for file parsing");
                 return -2;
         }
 
@@ -589,7 +654,7 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
 
         oh_conf_file = open(filename, O_RDONLY);
         if (oh_conf_file < 0) {
-                dbg("Configuration file '%s' could not be opened", filename);
+                err("Configuration file '%s' could not be opened", filename);
                 g_scanner_destroy(oh_scanner);
                 return -4;
         }
@@ -597,8 +662,10 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
         g_scanner_input_file(oh_scanner, oh_conf_file);
 
         for (i = 0; i < num_tokens; i++) {
-                g_scanner_scope_add_symbol(oh_scanner, 0, oh_conf_tokens[i].name,
-                                           (void *)((unsigned long)oh_conf_tokens[i].token));
+                g_scanner_scope_add_symbol(
+                        oh_scanner, 0,
+                        oh_conf_tokens[i].name,
+                        (void *)((unsigned long)oh_conf_tokens[i].token));
         }
 
         while (!done) {
@@ -613,8 +680,8 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
                 case HPI_CONF_TOKEN_HANDLER:
                         process_handler_token(oh_scanner);
                         break;
-                case HPI_CONF_TOKEN_PLUGIN:
-                        process_plugin_token(oh_scanner);
+                case HPI_CONF_TOKEN_DOMAIN:
+                        process_domain_token(oh_scanner);
                         break;
                 case G_TOKEN_STRING:
                         process_global_token(oh_scanner);
@@ -623,7 +690,7 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
                         /* need to advance it */
                         my_token = g_scanner_get_next_token(oh_scanner);
                         g_scanner_unexp_token(oh_scanner, G_TOKEN_SYMBOL,
-                                              NULL, "\"handle\" or \"plugin\"", NULL, NULL, 1);
+                                              NULL, "\"handle\" or \"domain\"", NULL, NULL, 1);
                         break;
                 }
         }
@@ -631,7 +698,7 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
         read_globals_from_env(1);
 
         if (close(oh_conf_file) != 0) {
-                dbg("Couldn't close file '%s'.", filename);
+                err("Couldn't close file '%s'.", filename);
                 g_scanner_destroy(oh_scanner);
                 return -5;
         }
@@ -640,13 +707,13 @@ int oh_load_config (char *filename, struct oh_parsed_config *config)
 
         g_scanner_destroy(oh_scanner);
 
-        trace("Done processing conf file.\nNumber of parse errors:%d", done);
+        dbg("Done processing conf file.\nNumber of parse errors:%d", done);
 
-        config->plugin_names = plugin_names;
         config->handler_configs = handler_configs;
+	config->domain_configs = domain_configs;
 
-        plugin_names = NULL;
         handler_configs = NULL;
+	domain_configs = NULL;
 
         return 0;
 }
@@ -666,44 +733,54 @@ SaErrorT oh_process_config(struct oh_parsed_config *config)
 
         if (!config) return SA_ERR_HPI_INVALID_PARAMS;
 
-        /* Initialize plugins */
-        for (node = config->plugin_names; node; node = node->next) {
-                char *plugin_name = (char *)node->data;
-                if (oh_load_plugin(plugin_name) == 0) {
-                        trace("Loaded plugin %s", plugin_name);
-                        config->plugins_loaded++;
-                } else {
-                        dbg("Couldn't load plugin %s", plugin_name);
-                        g_free(plugin_name);
-                }
-                config->plugins_defined++;
-        }
-
         /* Initialize handlers */
         for (node = config->handler_configs; node; node = node->next) {
                 GHashTable *handler_config = (GHashTable *)node->data;
-                if(oh_create_handler(handler_config) > 0) {
-                        trace("Loaded handler for plugin %s",
-                              (char *)g_hash_table_lookup(handler_config, "plugin"));
+		unsigned int hid = 0;
+		SaErrorT error = SA_OK;
+
+		error = oh_create_handler(handler_config, &hid);
+                if (error == SA_OK) {
+                        dbg("Loaded handler for plugin %s",
+                            (char *)g_hash_table_lookup(handler_config, "plugin"));
                         config->handlers_loaded++;
                 } else {
-                        dbg("Couldn't load handler for plugin %s",
+                        err("Couldn't load handler for plugin %s",
                             (char *)g_hash_table_lookup(handler_config, "plugin"));
-                        g_hash_table_destroy(handler_config);
+                        if (hid == 0) g_hash_table_destroy(handler_config);
                 }
                 config->handlers_defined++;
         }
 
+        /* Initialize domains */
+        for (node = config->domain_configs; node; node = node->next) {
+                GHashTable *domain_config = (GHashTable *)node->data;
+                SaHpiDomainIdT *did =
+                        (SaHpiDomainIdT *)g_hash_table_lookup(domain_config, "id");
+                if (*did == 0) config->default_domain = TRUE;
+                if (!oh_create_domain_from_table(domain_config)) {
+                        dbg("Created domain %u", *did);
+                        config->domains_loaded++;
+                } else {
+                        err("Couldn't load domain %u", (did) ? *did : 999999);
+                }
+                config->domains_defined++;
+        }
+
         return SA_OK;
 }
 
 void oh_clean_config(struct oh_parsed_config *config)
 {
-        /* Free list of plugin names read from configuration file. */
-        g_slist_free(config->plugin_names);
-
         /* Free list of handler configuration blocks */
         g_slist_free(config->handler_configs);
+
+        /* Free list of domain configuration blocks */
+        GSList *node = NULL;
+        for (node = config->domain_configs; node; node = node->next) {
+                g_hash_table_destroy((GHashTable *)node->data);
+        }
+        g_slist_free(config->domain_configs);
 }
 
 /**
@@ -717,11 +794,11 @@ int oh_get_global_param(struct oh_global_param *param)
         if (!param || !(param->type)) {
 
             if (!param) {
-                dbg("ERROR. Invalid parameters param NULL");
+                err("ERROR. Invalid parameters param NULL");
             }
 
             if (!param->type) {
-                dbg("ERROR. Invalid parameters param->type NULL");
+                err("ERROR. Invalid parameters param->type NULL");
             }
 
                 return -1;
@@ -756,15 +833,6 @@ int oh_get_global_param(struct oh_global_param *param)
                 case OPENHPI_DAT_SAVE:
                         param->u.dat_save = global_params.dat_save;
                         break;
-                //case OPENHPI_DEBUG:
-                //        param->u.dbg = global_params.dbg;
-                //        break;
-                //case OPENHPI_DEBUG_TRACE:
-                //        param->u.dbg_trace = global_params.dbg_trace;
-                //        break;
-                //case OPENHPI_DEBUG_LOCK:
-                //        param->u.dbg_lock = global_params.dbg_lock;
-                //        break;
                 case OPENHPI_PATH:
                         g_static_rec_mutex_lock(&global_params.lock);
                         strncpy(param->u.path,
@@ -787,7 +855,7 @@ int oh_get_global_param(struct oh_global_param *param)
                         g_static_rec_mutex_unlock(&global_params.lock);
                         break;
                 default:
-                        dbg("ERROR. Invalid global parameter %d!", param->type);
+                        err("ERROR. Invalid global parameter %d!", param->type);
                         return -2;
         }
 
@@ -803,7 +871,7 @@ int oh_get_global_param(struct oh_global_param *param)
 int oh_set_global_param(struct oh_global_param *param)
 {
         if (!param || !(param->type)) {
-                dbg("ERROR. Invalid parameters");
+                err("ERROR. Invalid parameters");
                 return -1;
         }
 
@@ -836,15 +904,6 @@ int oh_set_global_param(struct oh_global_param *param)
                 case OPENHPI_DAT_SAVE:
                         global_params.dat_save = param->u.dat_save;
                         break;
-                //case OPENHPI_DEBUG:
-                //        global_params.dbg = param->u.dbg;
-                //        break;
-                //case OPENHPI_DEBUG_TRACE:
-                //        global_params.dbg_trace = param->u.dbg_trace;
-                //        break;
-                //case OPENHPI_DEBUG_LOCK:
-                //        global_params.dbg_lock = param->u.dbg_lock;
-                //        break;
                 case OPENHPI_PATH:
                         g_static_rec_mutex_lock(&global_params.lock);
                         memset(global_params.path, 0, OH_MAX_TEXT_BUFFER_LENGTH);
@@ -870,31 +929,9 @@ int oh_set_global_param(struct oh_global_param *param)
                         g_static_rec_mutex_unlock(&global_params.lock);
                         break;
                 default:
-                        dbg("ERROR. Invalid global parameter %d!", param->type);
+                        err("ERROR. Invalid global parameter %d!", param->type);
                         return -2;
         }
 
         return 0;
 }
-
-//unsigned char oh_get_global_bool(oh_global_param_type type)
-//{
-//        if (!type) {
-//                dbg("ERROR. Invalid parameters");
-//                return 0;
-//        }
-//
-//        read_globals_from_env(0);
-//
-//        switch (type) {
-//                case OPENHPI_DEBUG:
-//                        return global_params.dbg;
-//                case OPENHPI_DEBUG_TRACE:
-//                        return global_params.dbg_trace;
-//                case OPENHPI_DEBUG_LOCK:
-//                        return global_params.dbg_lock;
-//                default:
-//                        dbg("ERROR. Invalid global parameter type %d!", type);
-//                        return 0;
-//        }
-//}
