@@ -10,7 +10,7 @@
  * full licensing terms.
  *
  * Author(s):
- *      Renier Morales <renierm@users.sf.net>
+ *      Renier Morales <renier@openhpi.org>
  *
  */
 
@@ -135,9 +135,9 @@ static void gen_domain_event(SaHpiDomainIdT target_id,
         gettimeofday(&tv1, NULL);
         e->event.Timestamp = (SaHpiTimeT) tv1.tv_sec *
                         1000000000 + tv1.tv_usec * 1000;
-        trace("domain %d %s domain %d", subject_id,
-              type == SAHPI_DOMAIN_REF_ADDED ? "added to" : "removed from",
-              target_id);
+        dbg("domain %d %s domain %d", subject_id,
+            type == SAHPI_DOMAIN_REF_ADDED ? "added to" : "removed from",
+            target_id);
         oh_evt_queue_push(&oh_process_q, e);
 }
 
@@ -153,7 +153,7 @@ static void update_drt(SaHpiDomainIdT target_id,
 
         domain = oh_get_domain(target_id);
         if (!domain) {
-                dbg("Warning. Could not update DRT. Domain %u not found.",
+                err("Warning. Could not update DRT. Domain %u not found.",
                     target_id);
                 return;
         }
@@ -223,7 +223,7 @@ static int connect2parent(struct oh_domain *domain, SaHpiDomainIdT parent_id)
 
         parent = oh_get_domain(parent_id);
         if (!parent) {
-                dbg("Couldn't get domain %d", parent_id);
+                err("Couldn't get domain %d", parent_id);
                 return -3;
         }
 
@@ -258,7 +258,7 @@ static int connect2peer(struct oh_domain *domain, SaHpiDomainIdT peer_id)
 
         peer = oh_get_domain(peer_id);
         if (!peer) {
-                dbg("Couldn't get domain %d", peer_id);
+                err("Couldn't get domain %d", peer_id);
                 return -3;
         }
 
@@ -373,7 +373,7 @@ SaErrorT oh_create_domain(SaHpiDomainIdT id,
         if (g_hash_table_lookup(oh_domains.table, &id)) {
                 domains_unlock();
                 g_free(domain);
-                dbg("Domain %u already exists; not creating twice.", id);
+                err("Domain %u already exists; not creating twice.", id);
                 return SA_ERR_HPI_INVALID_DOMAIN;
         }
 
@@ -444,20 +444,20 @@ SaErrorT oh_create_domain(SaHpiDomainIdT id,
         /* Establish child-parent relationship */
         if (child_of != SAHPI_UNSPECIFIED_DOMAIN_ID &&
             connect2parent(domain, child_of)) {
-                dbg("Error connecting domain %u to parent %u",
+                err("Error connecting domain %u to parent %u",
                     domain->id, child_of);
         }
 
         /* Establish peer relationships */
         if (peer_of != SAHPI_UNSPECIFIED_DOMAIN_ID &&
             connect2peer(domain, peer_of)) {
-                dbg("Error connection domain %u to peer %u",
+                err("Error connection domain %u to peer %u",
                     domain->id, peer_of);
         }
         
         domains_unlock();
 
-        trace("Domain %u has been created.", id);
+        dbg("Domain %u has been created.", id);
 
         return SA_OK;
 }
@@ -483,22 +483,24 @@ SaErrorT oh_create_domain_from_table(GHashTable *table)
         ai_readonly = (unsigned int *)g_hash_table_lookup(table, "ai_readonly");
 
         if (!id) {
-                dbg("Error creating a domain from configuration."
+                err("Error creating a domain from configuration."
                     " No domain id was given.");
                 return SA_ERR_HPI_INVALID_PARAMS;
-        } else if (*id == 0) {
-                dbg("Error creating domain. Configured domains"
-                    " cannot have an id of 0.");
-                return SA_ERR_HPI_INVALID_PARAMS;
+        }
+
+        if (id == 0) { /* ID == 0 is the default domain */
+                /* Default domain cannot be a peer or child of anyone */
+                child_of = NULL;
+                peer_of = NULL;
         }
 
         if (peer_of && entity_pattern) {
-                dbg("Warning creating domain %u. Entity pattern will be"
-                    " disregarded since a peer was specified.",
-                    *id);
+                warn("Warning creating domain %u. Entity pattern will be"
+                     " disregarded since a peer was specified.",
+                     *id);
         } else if (!peer_of &&
                    oh_compile_entitypath_pattern(entity_pattern, &epp)) {
-                dbg("Error creating domain %u. "
+                err("Error creating domain %u. "
                     "Invalid entity pattern given.", *id);
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
@@ -645,13 +647,13 @@ SaErrorT oh_drt_entry_get(SaHpiDomainIdT     did,
         GSList *node = NULL;
 
         if (did < 0 || !nextentryid || !drtentry) {
-                dbg("Error - Invalid parameters passed.");
+                err("Error - Invalid parameters passed.");
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
         domain = oh_get_domain(did);
         if (domain == NULL) {
-                dbg("no domain for id %d", did);
+                err("no domain for id %d", did);
                 return SA_ERR_HPI_INTERNAL_ERROR;
         }
 
