@@ -10,11 +10,13 @@
  * full licensing terms.
  *
  * Author(s):
- *      Renier Morales <renierm@users.sf.net>
+ *      Renier Morales <renier@openhpi.org>
  *
  */
 
+#include <config.h>
 #include <oh_init.h>
+#include <oh_ssl.h>
 #include <oh_config.h>
 #include <oh_plugin.h>
 #include <oh_domain.h>
@@ -33,7 +35,7 @@
 int oh_init(void)
 {
         static int initialized = 0;
-        struct oh_parsed_config config = {NULL, NULL, 0, 0, 0, 0};
+        struct oh_parsed_config config = { NULL, NULL, 0, 0, 0, 0, FALSE };
         struct oh_global_param config_param = { .type = OPENHPI_CONF };
         oh_entitypath_pattern epp;
         SaErrorT rval;
@@ -46,14 +48,21 @@ int oh_init(void)
 
         /* Initialize thread engine */
         oh_threaded_init();
-
+#ifdef HAVE_OPENSSL
+	/* Initialize SSL library */
+	if (oh_ssl_init()) {
+                err("SSL library intialization failed.");
+                data_access_unlock();
+		return SA_ERR_HPI_OUT_OF_MEMORY; /* Most likely */
+	}
+#endif
         /* Set openhpi configuration file location */
         oh_get_global_param(&config_param);
 
         rval = oh_load_config(config_param.u.conf, &config);
         /* Don't error out if there is no conf file */
         if (rval < 0 && rval != -4) {
-                dbg("Can not load config.");
+                err("Can not load config.");
                 data_access_unlock();
                 return SA_ERR_HPI_NOT_PRESENT;
         }
@@ -61,46 +70,48 @@ int oh_init(void)
         /* Initialize uid_utils */
         rval = oh_uid_initialize();
         if( (rval != SA_OK) && (rval != SA_ERR_HPI_ERROR) ) {
-                dbg("Unique ID intialization failed.");
+                err("Unique ID intialization failed.");
                 data_access_unlock();
                 return rval;
         }
-        trace("Initialized UID.");
+        dbg("Initialized UID.");
 
         /* Initialize handler table */
         oh_handlers.table = g_hash_table_new(g_int_hash, g_int_equal);
-        trace("Initialized handler table");
+        dbg("Initialized handler table");
 
         /* Initialize domain table */
         oh_domains.table = g_hash_table_new(g_int_hash, g_int_equal);
-        trace("Initialized domain table");
-
-        /* Create default domain */
-        if (oh_compile_entitypath_pattern("*", &epp)) {
-                data_access_unlock();
-                dbg("Could not compile entitypath pattern.");
-                return SA_ERR_HPI_ERROR;
-        }
-        
-        if (oh_create_domain(OH_DEFAULT_DOMAIN_ID,
-                             &epp, "DEFAULT",
-                             SAHPI_UNSPECIFIED_DOMAIN_ID,
-                             SAHPI_UNSPECIFIED_DOMAIN_ID,
-                             SAHPI_DOMAIN_CAP_AUTOINSERT_READ_ONLY,
-                             SAHPI_TIMEOUT_IMMEDIATE)) {
-                data_access_unlock();
-                dbg("Could not create first domain!");
-                return SA_ERR_HPI_ERROR;
-        }
-        trace("Created DEFAULT domain");
+        dbg("Initialized domain table");
 
         /* Initialize session table */
         oh_sessions.table = g_hash_table_new(g_int_hash, g_int_equal);
-        trace("Initialized session table");
+        dbg("Initialized session table");
 
-        /* Load plugins and create handlers*/
+        /* Load plugins, create handlers and domains */
         oh_process_config(&config);
 
+        /* Create default domain if it does not exist yet. */
+        if (!config.default_domain) {
+                if (oh_compile_entitypath_pattern("*", &epp)) {
+                        data_access_unlock();
+                        err("Could not compile entitypath pattern.");
+                        return SA_ERR_HPI_ERROR;
+                }
+        
+                if (oh_create_domain(OH_DEFAULT_DOMAIN_ID,
+                                     &epp, "DEFAULT",
+                                     SAHPI_UNSPECIFIED_DOMAIN_ID,
+                                     SAHPI_UNSPECIFIED_DOMAIN_ID,
+                                     SAHPI_DOMAIN_CAP_AUTOINSERT_READ_ONLY,
+                                     SAHPI_TIMEOUT_IMMEDIATE)) {
+                        data_access_unlock();
+                        err("Could not create first domain!");
+                        return SA_ERR_HPI_ERROR;
+                }
+                dbg("Created DEFAULT domain");
+        }
+
         /*
          * Wipes away configuration lists (plugin_names and handler_configs).
          * global_params is not touched.
@@ -112,31 +123,31 @@ int oh_init(void)
          * all of them failed to load, Then return with an error.
          */
         if (config.handlers_defined > 0 && config.handlers_loaded == 0) {
-                dbg("Warning: Handlers were defined, but none loaded.");
+                warn("Warning: Handlers were defined, but none loaded.");
         } else if (config.handlers_defined > 0 &&
                    config.handlers_loaded < config.handlers_defined) {
-                dbg("*Warning*: Not all handlers defined loaded."
-                    " Check previous messages.");
+                warn("*Warning*: Not all handlers defined loaded."
+                     " Check previous messages.");
         }
 
         if (config.domains_defined != config.domains_loaded) {
-                dbg("*Warning*: Not all domains defined where created."
-                    " Check previous messages.");
+                warn("*Warning*: Not all domains defined where created."
+                     " Check previous messages.");
         }
 
         /* this only does something if the config says to */
         oh_threaded_start();
 
-        trace("Set init state");
+        dbg("Set init state");
         initialized = 1;
         data_access_unlock();
         /* infrastructure initialization has completed at this point */
 
         /* Check if there are any handlers loaded */
         if (config.handlers_defined == 0) {
-                dbg("*Warning*: No handler definitions found in config file."
-                    " Check configuration file %s and previous messages",
-                    config_param.u.conf);
+                warn("*Warning*: No handler definitions found in config file."
+                     " Check configuration file %s and previous messages",
+                     config_param.u.conf);
         }
 
         /*
